SystemOrganization addCategory: #'Metacello-TestsMC'!
SystemOrganization addCategory: #'Metacello-TestsMC-Configurations'!
SystemOrganization addCategory: #'Metacello-TestsMC-Resources'!

Notification subclass: #MetacelloStopNotification
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloStopNotification methodsFor: 'read me' stamp: 'DaleHenrichs 2/3/2010 14:27'!
readme
	"Catch this notification in a unit test and then signal a failure or otherwise fail test.
	 Very useful when the code being debugged is triggered by the debugger (like algorithms used during printing) 
	"! !

TestResource subclass: #MetacelloAlternateResource
	instanceVariableNames: 'versionReferences monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloAlternateResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 12:39'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloAlternateResource methodsFor: 'running' stamp: 'dkh 1/12/2010 12:39'!
setUp
	super setUp.
	self
		setUpVersionReferences;
		setUpMonticelloRepository! !

!MetacelloAlternateResource methodsFor: 'running' stamp: 'dkh 1/12/2010 12:39'!
setUpMonticelloRepository
	"This method builds a fake repository with the version references from #buildReferences."

	monticelloRepository := MCDictionaryRepository new.
	versionReferences do: [ :reference |
		monticelloRepository basicStoreVersion: (MCVersion new
			setPackage:  (MCPackage new name: reference packageName)
			info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
			snapshot: (MCSnapshot fromDefinitions: (Array
				with: (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
				with: (MCClassDefinition name: reference packageName asSymbol superclassName: #Object category: reference packageName asSymbol instVarNames: #() comment: '')))
			dependencies: #()) ]! !

!MetacelloAlternateResource methodsFor: 'running' stamp: 'DaleHenrichs 01/20/2010 17:05'!
setUpVersionReferences
	"self reset"

	versionReferences := OrderedCollection new.
	versionReferences
		add: (GoferVersionReference name: 'GoferBar-dkh.24');
		add: (GoferVersionReference name: 'GoferBar-dkh.25');
		add: (GoferVersionReference name: 'GoferFoo-dkh.75');
		add: (GoferVersionReference name: 'GoferFoo-dkh.104')! !

!MetacelloAlternateResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 12:39'!
versionReferences
	^ versionReferences! !

TestResource subclass: #MetacelloAtomicConfigurationResource
	instanceVariableNames: 'monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 3/18/2010 12:08'!
baseline20Fan: spec 
	"self reset"
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		spec 
			package: 'GoferFan';
			yourself ].! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 09:31'!
baseline20Foo: spec 
	"self reset"
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		spec 
			package: 'GoferBar';
			package: 'GoferFoo';
			package: 'GoferBeau';
			package: 'GoferFaux';
			yourself ].! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 3/18/2010 12:08'!
baseline20MethodSourceFan

	^(self class sourceCodeAt: #baseline20Fan:) asString! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 10:12'!
baseline20MethodSourceFoo

	^(self class sourceCodeAt: #baseline20Foo:) asString! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 12:16'!
baseline25Foo: spec 
	"self reset"
	<version: '2.5-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		spec 
			package: 'GoferFoo' with: [spec requires: 'GoferFan' ];
			yourself.
		spec 
			project: 'GoferFan' with: [ "requires GoferBeau"
				spec
					className: 'MetacelloTestConfigurationOfAtomicFan';
					versionString: '2.0-baseline';
					loads: 'GoferFan';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 12:05'!
baseline25MethodSourceFoo

	^(self class sourceCodeAt: #baseline25Foo:) asString! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 11:43'!
linearProjectMethodSource

	^(self class sourceCodeAt: #project) asString copyReplaceAll: 'atomic' with: 'linear'! !

!MetacelloAtomicConfigurationResource methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:12'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 10:13'!
project
	"self reset"

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: #atomic.
	^project! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 10:12'!
projectMethodSource

	^(self class sourceCodeAt: #project) asString! !

!MetacelloAtomicConfigurationResource methodsFor: 'running' stamp: 'DaleHenrichs 3/18/2010 12:08'!
setUp
	super setUp.
	self
		setUpMonticelloRepository;
		setUpConfigurationOfAtomicFoo;
		setUpConfigurationOfLinearFoo;
		setUpConfigurationOfAtomicFan;
		yourself! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 3/18/2010 12:07'!
setUpConfigurationOfAtomicFan
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfAtomicFan-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline20Fan:'
						category: 'cat'
						timeStamp: ''
						source: self baseline20MethodSourceFan.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 12:05'!
setUpConfigurationOfAtomicFoo
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfAtomicFoo-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline20Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline20MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline25Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline25MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'version20Foo:'
						category: 'cat'
						timeStamp: ''
						source: self version20MethodSourceFoo.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 09:30'!
setUpConfigurationOfLinearFoo
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfLinearFoo-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self linearProjectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline20Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline20MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'version20Foo:'
						category: 'cat'
						timeStamp: ''
						source: self version20MethodSourceFoo.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:12'!
setUpMonticelloRepository
	"This method builds a fake repository with the version references from #buildReferences."
	"self reset"

	monticelloRepository := MCDictionaryRepository new.! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 09:29'!
version20Foo: spec 
	"self reset"
	<version: '2.0' imports: #('2.0-baseline')>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBar' with: 'GoferBar-dkh.1';
			package: 'GoferFoo' with: 'GoferFoo-dkh.4';
			package: 'GoferBeau' with: 'GoferBeau-dkh.15';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			yourself ].! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 09:29'!
version20MethodSourceFoo

	^(self class sourceCodeAt: #version20Foo:) asString! !

TestResource subclass: #MetacelloAtomicMonticelloResource
	instanceVariableNames: 'versionReferences monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloAtomicMonticelloResource methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:17'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 16:40'!
setUp
	super setUp.
	self
		setUpVersionReferences;
		setUpMonticelloRepository;
		setUpDependency! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 16:46'!
setUpDependency
	"self reset"

	| reference |
	reference := GoferVersionReference name: 'GoferUmbrella-dkh.4'.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: (Array
				with: (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
				with: (MCClassDefinition name: (reference packageName copyWithout: $-) asSymbol superclassName: #Object category: reference packageName asSymbol instVarNames: #() comment: '')))
		dependencies: (Array 
				with: (MCVersionDependency 
						package: (MCPackage new name: 'GoferBarDependency') 
						info: (monticelloRepository versionInfoFromVersionNamed: 'GoferBarDependency-dkh.4')) 
				with: (MCVersionDependency 
						package: (MCPackage new name: 'GoferFooDependency') 
						info: (monticelloRepository versionInfoFromVersionNamed: 'GoferFooDependency-lr.4'))))! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:22'!
setUpMonticelloRepository
	"This method builds a fake repository with the version references from #buildReferences."

	monticelloRepository := MCDictionaryRepository new.
	versionReferences do: [ :assoc | | reference superclassName |
		reference := assoc key.
		superclassName := assoc value.
		monticelloRepository basicStoreVersion: (MCVersion new
			setPackage:  (MCPackage new name: reference packageName)
			info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
			snapshot: (MCSnapshot fromDefinitions: (Array
				with: (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
				with: (MCClassDefinition name: (reference packageName copyWithout: $-) asSymbol superclassName: superclassName category: reference packageName asSymbol instVarNames: #() comment: '')))
			dependencies: #()) ]! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 3/18/2010 12:24'!
setUpVersionReferences
	"self reset"

	versionReferences := OrderedCollection new.
	versionReferences
		add: ((GoferVersionReference name: 'GoferFan-dkh.1') -> #GoferFar);
		add: ((GoferVersionReference name: 'GoferBar-dkh.1') -> #Object);
		add: ((GoferVersionReference name: 'GoferFoo-dkh.4') -> #GoferBeau);
		add: ((GoferVersionReference name: 'GoferFoo-dkh.5') -> #GoferBeau);
		add: ((GoferVersionReference name: 'GoferBeau-dkh.15') -> #GoferBar);
		add: ((GoferVersionReference name: 'GoferFaux-tg.30') -> #Object);
		add: ((GoferVersionReference name: 'GoferFar-dkh.4') -> #GoferFoo);
		add: ((GoferVersionReference name: 'GoferBarDependency-dkh.4') -> #Object);
		add: ((GoferVersionReference name: 'GoferFooDependency-lr.4') -> #Object);
		yourself! !

!MetacelloAtomicMonticelloResource methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:17'!
versionReferences
	^ versionReferences! !

TestResource subclass: #MetacelloConfigurationResource
	instanceVariableNames: 'monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 13:26'!
baseline20Fan: spec 
	"self reset"
	<version: '2.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '2.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Far' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '2.0';
					loads: #('GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:13'!
baseline20Foo: spec 
	"self reset"
	<version: '2.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-lr.branch.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			package: 'GoferBeau' with: 'GoferBeau-dkh.25';
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:11'!
baseline20MethodSourceFan

	^(self class sourceCodeAt: #baseline20Fan:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:13'!
baseline20MethodSourceFoo

	^(self class sourceCodeAt: #baseline20Foo:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:15'!
baseline30Fan: spec 
	"self reset"
	<version: '3.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:13'!
baseline30Foo: spec 
	"self reset"
	<version: '3.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: [
				spec 
					preLoadDoIt: #preloadDoIt;
					file: 'GoferFoo-lr.1' ];
			package: 'GoferBar' with: 'GoferBar-lr.branch.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			package: 'GoferBeau' with: 'GoferBeau-dkh.53';
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:10'!
baseline30MethodSourceFan

	^(self class sourceCodeAt: #baseline30Fan:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:13'!
baseline30MethodSourceFoo

	^(self class sourceCodeAt: #baseline30Foo:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:15'!
baseline35Fan: spec 
	"self reset"
	<version: '3.5'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.5';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:13'!
baseline35Foo: spec 
	"self reset"
	<version: '3.5'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-lr.branch.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.31';
			package: 'GoferBeau' with: 'GoferBeau-dkh.54';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' 'GoferFaux');
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:11'!
baseline35MethodSourceFan

	^(self class sourceCodeAt: #baseline35Fan:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:13'!
baseline35MethodSourceFoo

	^(self class sourceCodeAt: #baseline35Foo:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'DaleHenrichs 2/2/2010 23:13'!
baseline35MethodSourceProjectFie

	^(self class sourceCodeAt: #baseline35ProjectFie:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'DaleHenrichs 2/2/2010 23:14'!
baseline35ProjectFie: spec 
	"just projects"
	"self reset"

	<version: '3.5'>
	spec for: #common do: [
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.5';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Feaux' with: [
				spec
					className: 'MetacelloTestConfigurationOfFeaux';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFeaux';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:16'!
baseline40Fan: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationofFeaux' stamp: 'DaleHenrichs 2/2/2010 10:37'!
baseline40Feaux: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GeauxFoo' with:'GeauxFoo-lr.1';
			package: 'GeauxBar' with: 'GeauxBar-lr.branch.2';
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:12'!
baseline40Foo: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-lr.branch.2';
			package: 'GoferFaux' with: 'GoferFaux-tg.32';
			package: 'GoferBeau' with: 'GoferBeau-dkh.55';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' 'GoferFaux');
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:12'!
baseline40MethodSourceFan

	^(self class sourceCodeAt: #baseline40Fan:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationofFeaux' stamp: 'DaleHenrichs 2/2/2010 10:18'!
baseline40MethodSourceFeaux

	^(self class sourceCodeAt: #baseline40Feaux:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:12'!
baseline40MethodSourceFoo

	^(self class sourceCodeAt: #baseline40Foo:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFee' stamp: 'DaleHenrichs 2/2/2010 23:10'!
baseline40MethodSourceProjectFee

	^(self class sourceCodeAt: #baseline40ProjectFee:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'DaleHenrichs 2/2/2010 23:14'!
baseline40MethodSourceProjectFie

	^(self class sourceCodeAt: #baseline40ProjectFie:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFoe' stamp: 'DaleHenrichs 2/3/2010 10:24'!
baseline40MethodSourceProjectFoe

	^(self class sourceCodeAt: #baseline40ProjectFoe:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFum' stamp: 'DaleHenrichs 2/2/2010 10:42'!
baseline40MethodSourceProjectFum

	^(self class sourceCodeAt: #baseline40ProjectFum:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFee' stamp: 'DaleHenrichs 2/2/2010 23:11'!
baseline40ProjectFee: spec 
	"projects and packages"
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec 
			package: 'GeauxFaux' with: 'GeauxFaux-tg.32';
			package: 'GeauxBeau' with: 'GeauxBeau-dkh.55';
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'DaleHenrichs 2/2/2010 23:14'!
baseline40ProjectFie: spec 
	"just projects"
	"self reset"

	<version: '4.0'>
	spec for: #common do: [
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Feaux' with: [
				spec
					className: 'MetacelloTestConfigurationOfFeaux';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFeaux';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFoe' stamp: 'DaleHenrichs 2/3/2010 10:24'!
baseline40ProjectFoe: spec 
	"projects and packages"
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: '1';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFum' stamp: 'DaleHenrichs 2/2/2010 23:17'!
baseline40ProjectFum: spec 
	"master"
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Feaux' with: [
				spec
					className: 'MetacelloTestConfigurationOfFeaux';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFeaux';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'ProjectFie' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectFie';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfProjectFie';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'ProjectFee' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectFee';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfProjectFee';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:16'!
baseline50Fan: spec 
	"self reset"
	<version: '5.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '5.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/4/2010 13:05'!
baseline50Foo: spec 
	"self reset"
	<version: '5.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.2';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.34';
			package: 'GoferBeau' with: 'GoferBeau-dkh.55';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' 'GoferFaux');
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:12'!
baseline50MethodSourceFan

	^(self class sourceCodeAt: #baseline50Fan:) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:12'!
baseline50MethodSourceFoo

	^(self class sourceCodeAt: #baseline50Foo:) asString! !

!MetacelloConfigurationResource methodsFor: 'accessing' stamp: 'dkh 12/30/2009 15:14'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:15'!
preloadDoIt
	"self reset"

	Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result' put: true! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 11:00'!
preloadDoItMethodSource

	^(self class sourceCodeAt: #preloadDoIt) asString! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 3/14/2010 14:50'!
project
	"self reset"

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: #linear.
	^project! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:14'!
projectMethodSource

	^(self class sourceCodeAt: #project) asString! !

!MetacelloConfigurationResource methodsFor: 'running' stamp: 'DaleHenrichs 2/4/2010 11:24'!
setUp
	super setUp.
	self
		setUpMonticelloRepository;
		setUpConfigurationOfFoo;
		setUpConfigurationOfFeaux;
		setUpConfigurationOfProjectFie;
		setUpConfigurationOfProjectFee;
		setUpConfigurationOfFum;
		setUpConfigurationOfProjectFoe;
		setUpConfigurationOfFan;
		yourself! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'DaleHenrichs 2/4/2010 11:23'!
setUpConfigurationOfFan
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFan-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline20Fan:'
						category: 'cat'
						timeStamp: ''
						source: self baseline20MethodSourceFan.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline30Fan:'
						category: 'cat'
						timeStamp: ''
						source: self baseline30MethodSourceFan.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline35Fan:'
						category: 'cat'
						timeStamp: ''
						source: self baseline35MethodSourceFan.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline40Fan:'
						category: 'cat'
						timeStamp: ''
						source: self baseline40MethodSourceFan.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline50Fan:'
						category: 'cat'
						timeStamp: ''
						source: self baseline50MethodSourceFan.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationofFeaux' stamp: 'DaleHenrichs 2/2/2010 10:17'!
setUpConfigurationOfFeaux
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFeaux-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline40Feaux:'
						category: 'cat'
						timeStamp: ''
						source: self baseline40MethodSourceFeaux.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 2/2/2010 10:15'!
setUpConfigurationOfFoo
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFoo-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline20Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline20MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline30Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline30MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline35Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline35MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline40Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline40MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline50Foo:'
						category: 'cat'
						timeStamp: ''
						source: self baseline50MethodSourceFoo.
					MCMethodDefinition 
						className: className asString
						selector: 'preloadDoIt'
						category: 'cat'
						timeStamp: ''
						source: self preloadDoItMethodSource.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFum' stamp: 'DaleHenrichs 2/2/2010 11:00'!
setUpConfigurationOfFum
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFum-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline40ProjectFum:'
						category: 'cat'
						timeStamp: ''
						source: self baseline40MethodSourceProjectFum.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFee' stamp: 'DaleHenrichs 2/2/2010 23:11'!
setUpConfigurationOfProjectFee
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectFee-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline40ProjectFee:'
						category: 'cat'
						timeStamp: ''
						source: self baseline40MethodSourceProjectFee.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'DaleHenrichs 2/2/2010 23:14'!
setUpConfigurationOfProjectFie
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectFie-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline35ProjectFie:'
						category: 'cat'
						timeStamp: ''
						source: self baseline35MethodSourceProjectFie.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline40ProjectFie:'
						category: 'cat'
						timeStamp: ''
						source: self baseline40MethodSourceProjectFie.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFoe' stamp: 'DaleHenrichs 2/3/2010 10:25'!
setUpConfigurationOfProjectFoe
	"self reset"
	
	| reference className definitionArray |
	reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectFoe-dkh.1'.
	className := reference packageName asSymbol.
	definitionArray := {
					MCOrganizationDefinition categories: (Array with: className).
					MCClassDefinition name: className superclassName: #Object category: className instVarNames: #() comment: ''.
					MCMethodDefinition 
						className: className asString
						selector: 'project'
						category: 'cat'
						timeStamp: ''
						source: self projectMethodSource.
					MCMethodDefinition 
						className: className asString
						selector: 'baseline40ProjectFoe:'
						category: 'cat'
						timeStamp: ''
						source: self baseline40MethodSourceProjectFoe.
				}.
	monticelloRepository basicStoreVersion: (MCVersion new
		setPackage:  (MCPackage new name: reference packageName)
		info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
		snapshot: (MCSnapshot fromDefinitions: definitionArray)
		dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'running' stamp: 'DaleHenrichs 2/2/2010 10:07'!
setUpMonticelloRepository
	"This method builds a fake repository with the version references from #buildReferences."
	"self reset"

	monticelloRepository := MCDictionaryRepository new.! !

TestResource subclass: #MetacelloMonticelloResource
	instanceVariableNames: 'versionReferences monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloMonticelloResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 13:50'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 16:39'!
setUp
	super setUp.
	self
		setUpVersionReferences;
		setUpMonticelloRepository! !

!MetacelloMonticelloResource methodsFor: 'running' stamp: 'dkh 01/14/2010 11:25'!
setUpMonticelloRepository
	"This method builds a fake repository with the version references from #buildReferences."

	monticelloRepository := MCDictionaryRepository new.
	versionReferences do: [ :reference |
		monticelloRepository basicStoreVersion: (MCVersion new
			setPackage:  (MCPackage new name: reference packageName)
			info: (MCVersionInfo
				name: reference name
				id: UUID new
				message: 'This is a mock version'
				date: Date today
				time: Time now
				author: reference author
				ancestors: #())
			snapshot: (MCSnapshot fromDefinitions: (Array
				with: (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
				with: (MCClassDefinition name: (reference packageName copyWithout: $-) asSymbol superclassName: #Object category: reference packageName asSymbol instVarNames: #() comment: '')))
			dependencies: #()) ]! !

!MetacelloMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 16:40'!
setUpVersionReferences
	"self reset"

	versionReferences := OrderedCollection new.
	versionReferences
		add: (GoferVersionReference name: 'GoferBar-lr.branch.1');
		add: (GoferVersionReference name: 'GoferBar-lr.branch.2');
		add: (GoferVersionReference name: 'GoferBar-jf.1');
		add: (GoferVersionReference name: 'GoferBar-lr.1');
		add: (GoferVersionReference name: 'GoferFoo-lr.1');
		add: (GoferVersionReference name: 'GoferFoo-lr.2');
		add: (GoferVersionReference name: 'GoferFoo-lr.4');
		add: (GoferVersionReference name: 'GoferBeau-dkh.15');
		add: (GoferVersionReference name: 'GoferBeau-dkh.25');
		add: (GoferVersionReference name: 'GoferBeau-dkh.53');
		add: (GoferVersionReference name: 'GoferBeau-dkh.54');
		add: (GoferVersionReference name: 'GoferBeau-dkh.55');
		add: (GoferVersionReference name: 'GoferBeau-dkh.56');
		add: (GoferVersionReference name: 'GoferFaux-tg.30');
		add: (GoferVersionReference name: 'GoferFaux-tg.31');
		add: (GoferVersionReference name: 'GoferFaux-tg.32');
		add: (GoferVersionReference name: 'GoferFaux-tg.33');
		add: (GoferVersionReference name: 'GoferFaux-tg.34');
		add: (GoferVersionReference name: 'GoferFaux-tg.35');
		add: (GoferVersionReference name: 'GeauxBar-lr.branch.2');
		add: (GoferVersionReference name: 'GeauxFoo-lr.1');
		add: (GoferVersionReference name: 'GeauxFaux-tg.32');
		add: (GoferVersionReference name: 'GeauxBeau-dkh.55');
		add: (GoferVersionReference name: 'GeauxBeau-dkh.56');
		yourself! !

!MetacelloMonticelloResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 13:50'!
versionReferences
	^ versionReferences! !

GoferTest subclass: #MetacelloDictionaryRepositoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

MetacelloDictionaryRepositoryTest subclass: #MetacelloAtomicLoadOrderTest
	instanceVariableNames: 'loadType'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/16/2010 10:53'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		"using #atomic loadType means that package order isn't important ... 
			linear load order is GoferBar, GoferBeau, GoferFoo
			to test atomic load order, force an incorrect load order - which shouldn't matter for atomic loads"
		spec 
			package: 'GoferBar';
			package: 'GoferFoo' with: [ spec requires: 'GoferBar' ];
			package: 'GoferBeau' with: [ spec requires: 'GoferFoo' ];
			yourself ].! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/18/2010 09:42'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		"using #atomic loadType means that package order isn't important"
		spec 
			project: 'GoferFoo' with: [ 	"requires: 'GoferBeau'"
				spec
					className: 'MetacelloTestConfigurationOfAtomicFoo';
					versionString: '2.0-baseline';
					loads: 'GoferFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec 
			package: 'GoferBar';
			package: 'GoferFaux' with: [ spec requires: 'GoferFoo' ];
			package: 'GoferBeau'; 	"requires: 'GoferBar'"
			yourself ].! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/16/2010 12:02'!
baseline30: spec 
	<version: '3.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferBar';
			package: 'GoferBeau' with: [ 
				spec 
					requires: 'GoferBar';
					includes: #('GoferFoo' ) ]; 
			package: 'GoferFar' with: [ spec requires: #('GoferFoo' ) ]; 
			yourself.
		spec 
			project: 'GoferFoo' with: [ "requires GoferBeau"
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '2.0';
					loads: 'GoferFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/18/2010 12:27'!
baseline35: spec 
	<version: '3.5-baseline'>
	"loads correctly with atomic load, gives warning if loaded linearly...the explicit load of 
	 MetacelloTestConfigurationOfAtomicFan shouldn't break the chain of the atomic load"
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferBar';
			package: 'GoferBeau' with: [ 
				spec 
					requires: 'GoferBar';
					includes: #('GoferFoo' ) ]; 
			package: 'GoferFar' with: [ spec requires: #('GoferFoo' ) ]; "Far loaded after Foo, but Fan depends upon Far"
			yourself.
		spec 
			project: 'GoferFoo' with: [
				spec
					className: 'MetacelloTestConfigurationOfAtomicFoo';
					versionString: '2.5-baseline';
					loads: 'GoferFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/16/2010 16:37'!
baseline40: spec 
	<version: '4.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferUmbrella';
			yourself ].! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:25'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloAtomicConfigurationResource current monticelloRepository! !

!MetacelloAtomicLoadOrderTest methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:50'!
loadType

	loadType ~~ nil ifTrue: [ ^loadType ].
	^#atomic! !

!MetacelloAtomicLoadOrderTest methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:25'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloAtomicMonticelloResource current monticelloRepository! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:51'!
setUp

	super setUp.
	loadType := nil.! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:51'!
tearDown

	super tearDown.
	loadType := nil.! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 3/18/2010 12:12'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'GoferFar')
		ifTrue: [ aGoferInstance package: 'GoferFar' ].
	(self hasPackage: 'GoferFan')
		ifTrue: [ aGoferInstance package: 'GoferFan' ].
	(self hasPackage: 'GoferUmbrella')
		ifTrue: [ aGoferInstance package: 'GoferUmbrella' ].
	(self hasPackage: 'GoferBarDependency')
		ifTrue: [ aGoferInstance package: 'GoferBarDependency' ].
	(self hasPackage: 'GoferFooDependency')
		ifTrue: [ aGoferInstance package: 'GoferFooDependency' ].
	(self hasPackage: 'MetacelloTestConfigurationOfAtomicFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfAtomicFoo' ].
	(self hasPackage: 'MetacelloTestConfigurationOfLinearFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfLinearFoo' ]! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 09:36'!
testBaseline10LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '1.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 10:56'!
testBaseline10LoadLinear

	| project version |
	loadType := #linear.
	project := self project.
	version := project version: '1.0-baseline'.
	self should: [ version load ] raise: Warning! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 09:42'!
testBaseline20LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '2.0-baseline'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 10:57'!
testBaseline20LoadLinear

	| project version |
	loadType := #linear.
	project := self project.
	version := project version: '2.0-baseline'.
	self should: [ version load ] raise: Warning! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 12:05'!
testBaseline30LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '3.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFar-dkh.4').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 12:04'!
testBaseline30LoadLinear

	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '3.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFar-dkh.4').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 12:22'!
testBaseline35LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '3.5-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFan') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFan-dkh.1').
	wc := (GoferPackageReference name: 'GoferFar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFar-dkh.4').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 12:26'!
testBaseline35LoadLinear

	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '3.5-baseline'.
	self should: [ version load ] raise: Warning! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 16:47'!
testBaseline40LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '4.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferUmbrella') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferUmbrella-dkh.4').
	wc := (GoferPackageReference name: 'GoferBarDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBarDependency-dkh.4').
	wc := (GoferPackageReference name: 'GoferFooDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFooDependency-lr.4').! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 16:38'!
testBaseline40LoadLinear

	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '4.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferUmbrella') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferUmbrella-dkh.4').
	wc := (GoferPackageReference name: 'GoferBarDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBarDependency-dkh.4').
	wc := (GoferPackageReference name: 'GoferFooDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFooDependency-lr.4').! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 09:47'!
testIssue66
	"http://code.google.com/p/metacello/issues/detail?id=66"
	
	| project version wc |
	project := self project.
	version := project version: '2.0'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'.
	version := project version: '2.0-baseline'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 11:56'!
testVersion20LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '2.0'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/18/2010 09:40'!
version20: spec 
	<version: '2.0' imports: #('2.0-baseline') >
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		"using #atomic loadType means that package order isn't important"
		spec 
			project: 'GoferFoo' with: '2.0';
			yourself.
		spec 
			package: 'GoferBar' with: 'GoferBar-dkh.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			package: 'GoferBeau' with: 'GoferBeau-dkh.15';
			yourself ].! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloCurrentVersionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloCurrentVersionTest methodsFor: 'private' stamp: 'DaleHenrichs 2/5/2010 12:14'!
assertProject: project expectedVersionString: expectedVersionString expectedFidelity: expectedVersionStatus

	| cv versionStatus |
	cv := project currentVersion.
	expectedVersionString == nil 
		ifTrue: [
			^cv == nil
				ifFalse: [ self assert: cv versionStatus == #somethingLoaded ]].
	"validate current version"
	self assert: cv = (project version: expectedVersionString).
	self assert: (versionStatus := cv versionStatus) == expectedVersionStatus.! !

!MetacelloCurrentVersionTest methodsFor: 'running' stamp: 'DaleHenrichs 2/2/2010 23:21'!
setUp

	super setUp.
	gofer repository: self configurationRepository! !

!MetacelloCurrentVersionTest methodsFor: 'running' stamp: 'DaleHenrichs 2/8/2010 15:40'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'GeauxFoo')
		ifTrue: [ aGoferInstance package: 'GeauxFoo' ].
	(self hasPackage: 'GeauxBar')
		ifTrue: [ aGoferInstance package: 'GeauxBar' ].
	(self hasPackage: 'GeauxFaux')
		ifTrue: [ aGoferInstance package: 'GeauxFaux' ].
	(self hasPackage: 'GeauxBeau')
		ifTrue: [ aGoferInstance package: 'GeauxBeau' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFum')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFum' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFoo' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFeaux')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFeaux' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectFie')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectFie' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectFoe')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectFoe' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectFee')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectFee' ].! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/5/2010 14:37'!
testCompareCurrentVersion

	| version cv fum projectFie projectFee projectFoe foo feaux map |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	gofer 
		version: 'GeauxBeau-dkh.56';
		load.
	version := feaux version: '4.0'.
	version load: 'GeauxFoo'.
	version := projectFoe version: '4.0'.
	version load: #('ALL').
	
	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

	foo currentVersion packages do: [:pkg |
		pkg isPackageLoaded
			ifTrue: [ 
				self assert: 
					(pkg 
						compareRelativeCurrentVersion: #= 
						targetVersionStatus: nil 
						using: pkg loader).
				self assert: (pkg 
						compareCurrentVersion: #= 
						targetVersionStatus: nil
						using: pkg loader) ]].

	feaux currentVersion packages do: [:pkg |
		pkg isPackageLoaded
			ifTrue: [ 
				self assert: 
					(pkg 
						compareRelativeCurrentVersion: #= 
						targetVersionStatus: nil 
						using: pkg loader).
				self assert: (pkg 
						compareCurrentVersion: #= 
						targetVersionStatus: nil
						using: pkg loader) ]].

	projectFie currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader).
		self assert: (prj 
				compareCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader) ].

	projectFee currentVersion packages do: [:pkg |
		pkg isPackageLoaded
			ifTrue: [ 
				self assert: 
					(pkg 
						compareRelativeCurrentVersion: #> 
						targetVersionStatus: nil 
						using: pkg loader).
				self assert: (pkg 
						compareCurrentVersion: #> 
						targetVersionStatus: nil
						using: pkg loader) ]].
	projectFee currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader).
		self assert: (prj 
				compareCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader) ].

	projectFoe currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #= 
				targetVersionStatus: #(allLoadedToSpec) 
				using: prj loader).
		self deny: (prj 
				compareCurrentVersion: #= 
				targetVersionStatus: #(allLoadedToSpec) 
				using: prj loader) ].

	map := Dictionary new.
	map at: 'Feaux' put: #(loadedToSpec).
	map at: 'Foo' put: #(loadedToSpec).
	map at: 'ProjectFie' put: #(loadedToSpec).
	map at: 'ProjectFee' put: #(loadedMatchConstraints).
	fum currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #>= 
				targetVersionStatus: (map at: prj name) 
				using: prj loader).
		self assert: (prj 
				compareCurrentVersion: #>= 
				targetVersionStatus: (map at: prj name) 
				using: prj loader) ].! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/3/2010 00:06'!
testFeaux40Loaded

	| version fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Feaux').

	self assertProject: foo expectedVersionString: nil expectedFidelity: nil.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/5/2010 13:55'!
testFoe40AllLoaded

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := feaux version: '4.0'.
	version load: 'GeauxFoo'.
	version := projectFoe version: '4.0'.
	version load: #('ALL').
	gofer 
		version: 'GeauxBeau-dkh.56';
		load.
	
	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:19'!
testFoe40Loaded

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := projectFoe version: '4.0'.
	version load: #('Foo').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:22'!
testFoe40LoadedFoo40Loaded

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := projectFoe version: '4.0'.
	version load: #('Foo').
	version := foo version: '4.0'.
	version load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:25'!
testFoe40LoadedFoo40Loaded1LaterPackage

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := projectFoe version: '4.0'.
	version load: #('Foo').
	version := foo version: '4.0'.
	version load.
	gofer
		version: 'GoferFaux-tg.34'; 
		load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:27'!
testFoe40LoadedFoo50Loaded
	"isCurrent and findCurrentVersion gave wrong answers for this scenario in 1.0-beta.22"

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := foo version: '5.0'.
	version load.

	self assertProject: foo expectedVersionString: '5.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 13:35'!
testFoo20Feaux40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Feaux').
	version := foo version: '2.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/3/2010 00:02'!
testFoo20Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '2.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/4/2010 20:21'!
testFoo4020Loaded

	| version cv fum projectFie projectFee foo feaux repo |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	repo := self monticelloRepository.

	version := foo version: '3.0'.
	version load.
	self assertProject: foo expectedVersionString: '3.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

	"Load exact match to 2.0"
	Gofer it
		repository: repo;
		version: 'GoferBeau-dkh.25'; 
		load.

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:04'!
testFoo403540Loaded1PackageLater

	| version cv fum projectFie projectFee foo feaux repo |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	repo := self monticelloRepository.

	version := foo version: '4.0'.
	version load: #('1' ).
	
	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

	"Load partial exact match to 3.5"
	Gofer it
		repository: repo;
		version: 'GoferBar-lr.branch.1'; 
		version: 'GoferFoo-lr.1'; 
		load.

	self assertProject: foo expectedVersionString: '3.5' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '3.5' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

	"reload version 4.0"
	version load: '1'.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

	"Later package version matches constraints"
	Gofer it
		repository: repo;
		version: 'GoferFaux-tg.34'; 
		load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:07'!
testFoo40Feaux40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Feaux' 'Foo').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:09'!
testFoo40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Foo').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/3/2010 00:09'!
testFoo40Loaded1Package1EarlierPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '4.0'.
	version load: #('GoferFaux' 'GoferBar' ).
	gofer
		version: 'GoferFaux-tg.31'; 
		load.

	self assertProject: foo expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:19'!
testFoo40Loaded1Package1LaterPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '4.0'.
	version load: #('GoferFaux' 'GoferBar' ).
	gofer
		version: 'GoferFaux-tg.34'; 
		load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:20'!
testFoo40Loaded2Packages

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '4.0'.
	version load: #('GoferFoo' 'GoferBeau' ).

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/3/2010 00:10'!
testFoo40LoadedEarlierPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Foo').
	gofer
		version: 'GoferFaux-tg.31'; 
		load.

	self assertProject: foo expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:22'!
testFoo40LoadedLaterPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Foo').
	gofer
		version: 'GoferFaux-tg.34'; 
		load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:24'!
testFoo50Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '5.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '5.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects and packages' stamp: 'DaleHenrichs 2/3/2010 00:07'!
testProjectFee40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('ProjectFee').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects and packages' stamp: 'DaleHenrichs 2/3/2010 00:07'!
testProjectFee40Loaded2Packages

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := projectFee version: '4.0'.
	version load: #('GeauxFaux' 'GeauxBeau').

	self assertProject: foo expectedVersionString: nil expectedFidelity: nil.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects and packages' stamp: 'DaleHenrichs 2/6/2010 13:37'!
testProjectFee40Loaded2PackagesEarlierFoo

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := projectFee version: '4.0'.
	version load: #('GeauxFaux' 'GeauxBeau').
	version := foo version: '2.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #somethingLoaded.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 09:26'!
testProjectFie40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('ProjectFie').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/3/2010 00:04'!
testProjectFie40ProjectFee40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('ProjectFee' 'ProjectFie').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloDetermineCurrentVersionForLoadTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'running' stamp: 'DaleHenrichs 2/4/2010 10:50'!
setUp

	super setUp.
	gofer repository: self configurationRepository! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'running' stamp: 'DaleHenrichs 2/8/2010 15:48'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'MetacelloTestConfigurationOfFan')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFan' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFoo' ].! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 13:26'!
test001

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '3.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	"When we load version 2.0 of fan, we recognize that '3.0' of foo is the currentVersion (#allLoadedToSpec 
	 or #loadedToSpec and latestVersion), so we load the packages from version 3.0 of foo instead" 
	version := fan version: '2.0'.
	version load: 'Foo'.

	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/21/2010 10:20'!
test002

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '5.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	"load older version of 1 package (that doesn't match spec of earlier version)"
	gofer
		version: 'GoferFaux-tg.33'; 
		load.

	version := fan version: '2.0'.
	self flag: 'revisit this'.
	"self 
		should: [ version load: 'Foo' ]
		raise: MetacelloProjectSpecLoadConflict"
	version load: 'Foo'! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 13:27'!
test003

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '5.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	"load later version of 1 package beyond the last version of foo 5.0"
	gofer
		version: 'GoferFaux-tg.35'; 
		load.

	version := fan version: '2.0'.
	version load: 'Foo'.

	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.55').! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 13:27'!
test004

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '5.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	version := fan version: '2.0'.
	version load: 'Far'.

	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.55').! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'dkh 1/12/2010 14:46'!
alternateRepository
	"MetacelloAlternateResource reset"

	^ MetacelloAlternateResource current monticelloRepository! !

!MetacelloDictionaryRepositoryTest methodsFor: 'utilities' stamp: 'DaleHenrichs 03/19/2010 14:30'!
cleanUpChangeSets
	"excess change sets can cause a noticeable slow down in monticello performance"
	
	| removals set|
	(ChangeSet respondsTo: #allChangeSets) ifFalse: [ ^self ].
	removals := OrderedCollection new.
	(set := ChangeSet perform: #allChangeSets) do: [:cs |
		(cs name beginsWith: 'MC')
			ifTrue: [
				cs name size >= 3
					ifTrue: [ | post |
						post := cs name copyFrom: 3 to: cs name size.
						post asInteger printString = post 
							ifTrue: [ removals add: cs ]]]].
	removals do: [:cs | set remove: cs ].
	removals := OrderedCollection new.
	(set := ChangeSet perform: #allChangeSets) do: [:cs |
		((cs name beginsWith: 'GoferBar') 
			or: [ (cs name beginsWith: 'GoferFoo')
				or: [ (cs name beginsWith: 'GoferFaux')
					or: [ (cs name beginsWith: 'GoferBeau')
						or: [ (cs name beginsWith: 'MetacelloTestConfiguration')]]]])
			ifTrue: [removals add: cs ]].
	removals do: [:cs | set remove: cs ].! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'dkh 1/12/2010 14:46'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloConfigurationResource current monticelloRepository! !

!MetacelloDictionaryRepositoryTest methodsFor: 'utilities' stamp: 'dkh 12/30/2009 10:33'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'dkh 1/6/2010 20:43'!
loadType

	^#linear! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'dkh 1/12/2010 13:51'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloMonticelloResource current monticelloRepository! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'DaleHenrichs 3/6/2010 07:57'!
project

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: self loadType.
	^project! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'DaleHenrichs 3/6/2010 07:59'!
setUp
	| repo |
	super setUp.
	repo := self monticelloRepository.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.
	repo := self alternateRepository.
	Smalltalk at: #'Metacello_Configuration_Test_Alternate_Repository' put: repo.
	repo := self configurationRepository.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'DaleHenrichs 3/12/2010 10:10'!
tearDown
	| aGofer |
	super tearDown.
	aGofer := Gofer new.
	self tearDownPackages: aGofer.
	aGofer references notEmpty ifTrue: [ aGofer unload ].
	Smalltalk removeKey: #'Metacello_Gofer_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Alternate_Repository' ifAbsent: [].
	self cleanUpChangeSets! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'DaleHenrichs 2/8/2010 15:46'!
tearDownPackages: aGoferInstance

	(self hasPackage: 'GoferFoo')
		ifTrue: [ aGoferInstance package: 'GoferFoo' ].
	(self hasPackage: 'GoferBar')
		ifTrue: [ aGoferInstance package: 'GoferBar' ].
	(self hasPackage: 'GoferFaux')
		ifTrue: [ aGoferInstance package: 'GoferFaux' ].
	(self hasPackage: 'GoferBeau')
		ifTrue: [ aGoferInstance package: 'GoferBeau' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFoo' ].! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloGoferBasedLoaderTest
	instanceVariableNames: 'postloadAnswer postLoadExecuted preLoadExecuted'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

MetacelloGoferBasedLoaderTest subclass: #MetacelloGoferBasedAtomicLoaderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 01/15/2010 15:58'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	super baseline10: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 4/9/2010 11:39'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	super baseline11: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 01/15/2010 15:58'!
baselineIssue40: spec 
	<version: 'Issue40-baseline'>
	
	super baselineIssue40: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 01/15/2010 15:59'!
baselineMoose: spec 
	<version: '1.0-Moose'>
	
	super baselineMoose: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'accessing' stamp: 'dkh 1/6/2010 20:44'!
loadType

	^#atomic! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 01/15/2010 15:59'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	super version10: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 01/15/2010 15:59'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline' )>
	
	super version11: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/19/2010 15:13'!
version30: spec 
	<version: '3.0'>
	
	super version30: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/9/2010 11:23'!
version31: spec 
	<version: '3.1'>
	
	super version31: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/19/2010 15:13'!
version40: spec 
	<version: '4.0'>
	
	super version40: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/19/2010 15:13'!
version50: spec 
	<version: '5.0'>
	
	super version50: spec! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'dkh 12/30/2009 15:01'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			yourself ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 4/9/2010 11:40'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: [
				spec 
					preLoadDoIt: #preloadExecute;
					postLoadDoIt: #postloadExecute ];
			yourself ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'dkh 1/12/2010 13:11'!
baselineIssue40: spec 
	<version: 'Issue40-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar' with: [
				spec repository: 'dictionary://Metacello_Configuration_Test_Alternate_Repository' ];
			yourself ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 1/20/2010 09:59'!
baselineMoose: spec 
	<version: '1.0-Moose'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFaux' with: [
				spec file: 'GoferFaux-' ];
			yourself ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'doits' stamp: 'DaleHenrichs 4/9/2010 12:31'!
postloadExecute

	postLoadExecuted := true! !

!MetacelloGoferBasedLoaderTest methodsFor: 'doits' stamp: 'dkh 1/6/2010 21:19'!
postloadSupplyingAnswers

	postloadAnswer := ProvideAnswerNotification signal: 'postload'.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'doits' stamp: 'DaleHenrichs 4/9/2010 11:40'!
preloadExecute

	preLoadExecuted := true! !

!MetacelloGoferBasedLoaderTest methodsFor: 'running' stamp: 'DaleHenrichs 4/9/2010 11:22'!
setUp

	super setUp.
	Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result' put: false.
	preLoadExecuted := postLoadExecuted := false! !

!MetacelloGoferBasedLoaderTest methodsFor: 'running' stamp: 'DaleHenrichs 01/20/2010 16:58'!
tearDown
	super tearDown.
	Smalltalk removeKey: #'Metacello_Configuration_Test_DoIt_Result' ifAbsent: [].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/9/2010 11:42'!
testBaseline11PrePostLoadFetch

	| project version |
	project := self project.
	version := project version: '1.1-baseline'.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version fetch.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/9/2010 13:18'!
testBaseline11PrePostLoadLoad

	| project version loader |
	project := self project.
	version := project version: '1.1-baseline'.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:34'!
testBaselineFetch

	| project version loader files |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version fetch.
	files := #('GoferFoo-lr.4' 'GoferBar-lr.1') asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | 
		files remove: pkgDirective file ifAbsent: [ self assert: false ]].
	loader loadDirective versionDirectivesDo: [:vrsnDirective |
		vrsnDirective loader ~~ nil
			ifTrue: [ | spec |
				spec := vrsnDirective spec.
				self assert: (spec isKindOf: MetacelloVersionSpec) ]].
	self assert: files isEmpty! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 01/14/2010 11:56'!
testBaselineLoad

	| project version wc |
	project := self project.
	version := project version: '1.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-lr.1'! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 09:32'!
testBaselineRecord

	| project version loader files |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version record.
	files := #('GoferFoo' 'GoferBar') asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | 
		files remove: pkgDirective packageName ifAbsent: [ self assert: false ]].
	self assert: files isEmpty! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/4/2010 20:07'!
testIssue40Baseline

	| project version wc1 wc2 |
	project := self project.
	version := project version: 'Issue40-baseline'.
	version load.
	wc1 := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: wc1 repositoryGroup repositories size = 2.
	self assert: (wc1 repositoryGroup includes: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	self assert: (wc1 ancestry ancestors first name = 'GoferFoo-lr.4').
	wc2 := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc2 ancestry ancestors first name = 'GoferBar-dkh.25').
	self assert: wc2 repositoryGroup repositories size = 2.
	self assert: (wc2 repositoryGroup includes: (Smalltalk at: #'Metacello_Configuration_Test_Alternate_Repository')).! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:56'!
testIssue49PartialLoadA

	| project version wc |
	project := self project.
	version := project version: '4.0'.
	version load: '1'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.branch.2').
	self should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ] raise: Error.
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:23'!
testIssue49PartialLoadB

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	self should: [ (GoferPackageReference name: 'GoferBar') workingCopy ] raise: Error.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:57'!
testIssue49PartialLoadC

	| project version wc |
	project := self project.
	version := project version: '4.0'.
	version load: '1'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.branch.2').
	self should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ] raise: Error.
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:57'!
testIssue49PartialLoadD

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	self should: [ (GoferPackageReference name: 'GoferBar') workingCopy ] raise: Error.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '4.0'.
	version load: '1'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:26'!
testIssue49PartialLoadE

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	self should: [ (GoferPackageReference name: 'GoferBar') workingCopy ] raise: Error.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '4.0'.
	version load: '3'. "should get error, since there is no GoferBeau package in 5.0"! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:55'!
testIssue49PartialLoadF

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '4.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:55'!
testIssue49PartialLoadG

	| project version wc |
	project := self project.
	version := project version: '4.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.branch.2').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.32').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '5.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:11'!
testIssue59PackageSpecRepositoryOverrides
	"test for Issue 59: http://code.google.com/p/metacello/issues/detail?id=59"
	
	| project version wc repoSpec pkg loader |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	loader := pkg loader.
	loader loaderPolicy: (MetacelloLoaderPolicy overrideRepositories: (OrderedCollection with: MCDictionaryRepository new)).
	self should: [ pkg load ] raise: Error.
	loader loaderPolicy: (MetacelloLoaderPolicy overrideRepositories: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository'))).
	pkg load.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 15:14'!
testMooseBaselineLoad

	| project version wc test |
	project := self project.
	version := project version: '1.0-Moose'.
	version load.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.35').! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:34'!
testProjectFetch

	| project version wc files loader |
	project := self project.
	version := project version: '3.0'.
	loader := version fetch.
	files := #('MetacelloTestConfigurationOfFoo-dkh.1' 'GoferFoo-lr.1' 'GoferBar-lr.branch.1' 'GoferFaux-tg.30' 'GoferBeau-dkh.53' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | file |
		file := pkgDirective file.
		self assert: (files indexOf: file) = 1.
		files remove: file ifAbsent: [ self assert: false ]].
	loader loadDirective versionDirectivesDo: [:vrsnDirective |
		vrsnDirective loader ~~ nil
			ifTrue: [ | spec |
				spec := vrsnDirective spec.
				self assert: (spec isKindOf: MetacelloVersionSpec) ]].
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result')! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/1/2010 13:55'!
testProjectLoad

	| project version wc |
	project := self project.
	version := project version: '3.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.branch.1').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.30').
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result')! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/9/2010 11:24'!
testProjectPrePostLoad

	| project version |
	project := self project.
	version := project version: '3.1'.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:19'!
testProjectRecord

	| project version names loader |
	project := self project.
	version := project version: '3.0'.
	loader := version record.
	names := #('MetacelloTestConfigurationOfFoo' 'GoferFoo' 'GoferBar' 'GoferFaux' 'GoferBeau' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective packageName.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result')! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/6/2010 21:19'!
testRepositoryOverrides

	| project version wc |
	project := self project.
	version := project version: '1.0'.
	version repositoryOverrides: (OrderedCollection with: MCDictionaryRepository new).
	self 
		should: [ version load ]
		raise: Error.
	version repositoryOverrides: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:22'!
testRepositoryOverridesFetch

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	version repositoryOverrides: (OrderedCollection with: MCDictionaryRepository new).
	self 
		should: [ version fetch ]
		raise: Error.
	version repositoryOverrides: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	loader := version fetch.
	names := #('GoferFoo-lr.1' 'GoferBar-jf.1' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective file.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:23'!
testRepositoryOverridesRecord

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	version repositoryOverrides: (OrderedCollection with: MCDictionaryRepository new).
	self 
		shouldnt: [ version record ]
		raise: Error.
	version repositoryOverrides: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	loader := version record.
	names := #('GoferFoo' 'GoferBar' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective packageName.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/6/2010 21:20'!
testSupplyingAnswerLoad

	| project version wc |
	project := self project.
	version := project version: '1.1'.
	self deny: postloadAnswer = 'postload answer'.
	version load.
	self assert: postloadAnswer = 'postload answer'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:34'!
testVersionFetch

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	loader := version fetch.
	names := #('GoferFoo-lr.1' 'GoferBar-jf.1' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective file.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].
	loader loadDirective versionDirectivesDo: [:vrsnDirective |
		vrsnDirective loader ~~ nil
			ifTrue: [ | spec |
				spec := vrsnDirective spec.
				self assert: (spec isKindOf: MetacelloVersionSpec) ]].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/6/2010 21:19'!
testVersionLoad

	| project version wc |
	project := self project.
	version := project version: '1.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:24'!
testVersionRecord

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	loader := version record.
	names := #('GoferFoo' 'GoferBar' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective packageName.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'dkh 1/6/2010 20:38'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			yourself. ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'dkh 1/6/2010 20:39'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: [
				spec
					file: 'GoferFoo-lr.1';
					supplyingAnswers: #(#('postload' 'postload answer'));
					postLoadDoIt: #postloadSupplyingAnswers ];
			package: 'GoferBar' with: 'GoferBar-jf.1';
			yourself. ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/11/2010 23:22'!
version30: spec 
	<version: '3.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/9/2010 11:40'!
version31: spec 
	<version: '3.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					preLoadDoIt: #preloadExecute;
					postLoadDoIt: #postloadExecute;
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/11/2010 23:22'!
version40: spec 
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('1');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: '2' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('2');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: '3' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.

		spec
			group: '4' with: #('1' '2') ].! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/11/2010 23:23'!
version50: spec 
	<version: '5.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '5.0';
					loads: #('1');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: '2' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '5.0';
					loads: #('2');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.

		spec
			group: '4' with: #('1' '2') ].! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloGoferFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloGoferFunctionalTest methodsFor: 'baselines' stamp: 'DaleHenrichs 1/20/2010 09:58'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
	spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			package: 'GoferFaux';
			yourself ].! !

!MetacelloGoferFunctionalTest methodsFor: 'accessing' stamp: 'dkh 12/30/2009 10:37'!
repositorySpec

	| project version |
	project := self project.
	version := project version: '1.0-baseline'.
	^version spec repositorySpecs first.! !

!MetacelloGoferFunctionalTest methodsFor: 'running' stamp: 'dkh 1/12/2010 14:18'!
tearDown
	super tearDown.
	MetacelloMonticelloResource reset. "testCommitPackageSpec modifies the repository resource"! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 12/22/2009 11:48'!
testBasics
	| repoSpec repo |
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	self assert: repoSpec type = 'dictionary'.
	self assert: repo class == MCDictionaryRepository.! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 12:18'!
testCommitNewPackageSpec
	| repoSpec repo project packagesNeedSaving allVersionsSize packageName |
	project := self project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	gofer repository: repo.
	gofer 
		package: 'GoferFoo'; 
		package: 'GoferBar'; 
		load.
	"Create new package"
	packageName := 'GoferFaux'.
	PackageInfo registerPackageName: packageName.
	MCWorkingCopy forPackage: (MCPackage new name: packageName).
	(MCClassDefinition 
		name: (packageName copyWithout: $-) asSymbol 
		superclassName: #Object 
		category: packageName asSymbol 
		instVarNames: #() 
		comment: '') createClass.
	self assert: (packagesNeedSaving := project packagesNeedSaving: '1.0-baseline') notEmpty.
	packagesNeedSaving do: [:assoc | | gof |
		gof := Gofer new.
		gof disablePackageCache.
		gof repository: assoc value.
		gof package: assoc key name.
		gof commit: 'testing' ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 1/12/2010 14:32'!
testCommitPackageSpec
	| repoSpec repo project packagesNeedSaving allVersionsSize |
	project := self project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	gofer repository: repo.
	gofer 
		package: 'GoferFoo'; 
		package: 'GoferBar'; 
		load.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	self assert: (packagesNeedSaving := project packagesNeedSaving: '1.0-baseline') notEmpty.
	packagesNeedSaving do: [:assoc | | gof |
		gof := Gofer new.
		gof disablePackageCache.
		gof repository: assoc value.
		gof package: assoc key name.
		gof commit: 'testing' ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 01/14/2010 14:27'!
testCommitPackageVersion
	| repoSpec repo project packagesNeedSaving allVersionsSize |
	project := self project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	gofer repository: repo.
	gofer 
		package: 'GoferFoo'; 
		package: 'GoferBar'; 
		load.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	self assert: (packagesNeedSaving := project packagesNeedSaving: '1.0') notEmpty.
	packagesNeedSaving do: [:assoc | | gof |
		gof := Gofer new.
		gof disablePackageCache.
		gof repository: assoc value.
		gof package: assoc key name.
		gof commit: 'testing' ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 15:14'!
testComparison

	| blk |
	blk := [:file1 :operator :file2 | | ref1 ref2 |
		ref1 := GoferResolvedReference name: file1.
		ref2 := GoferResolvedReference name: file2.
		ref1 compare: ref2 using: operator].
	self assert: (blk value: 'GoferFaux-tg.34' value: #>= value: 'GoferFaux-tg.32').
	self assert: (blk value: 'GoferFaux-tg.32' value: #<= value: 'GoferFaux-tg.34').
	self assert: (blk value: 'GoferBar-lr.branch.2' value: #> value: 'GoferBar-lr.branch.1').
	self assert: (blk value: 'GoferBar-lr.1' value: #> value: 'GoferBar-lr.branch.1').
	self assert: (blk value: 'GoferBar-lr.1' value: #> value: 'GoferBar-jf.1').! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 1/12/2010 15:00'!
testIssue40PackageResolution

	|  ref pkgBar pkgFoo |
	pkgBar := GoferPackageReference name: 'GoferFoo'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 4.
	gofer repository: self alternateRepository.
	pkgBar := GoferPackageReference name: 'GoferBar'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 25.
	self assert: ref author = 'dkh'.
	pkgFoo := GoferPackageReference name: 'GoferFoo'.
	ref := pkgFoo resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 104.
	gofer
		package: 'GoferBar';
		package: 'GoferFoo';
		load.
	self assert: pkgBar workingCopy ancestry ancestors first name = 'GoferBar-dkh.25'.
	self assert: pkgFoo workingCopy ancestry ancestors first name = 'GoferFoo-dkh.104'.! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 1/12/2010 15:18'!
testIssue40VersionResolution

	|  ref pkgBar pkgFoo |
	pkgBar := GoferVersionReference name: 'GoferFoo-lr.2'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 2.
	gofer repository: self alternateRepository.
	pkgBar := GoferVersionReference name: 'GoferBar-jf.1'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 1.
	self assert: ref author = 'jf'.
	ref := (GoferVersionReference name: 'GoferBar-dkh.24') resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 24.
	self assert: ref author = 'dkh'.
	pkgFoo := GoferVersionReference name: 'GoferFoo-dkh.75'.
	ref := pkgFoo resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 75.
	gofer
		version: 'GoferBar-jf.1';
		version: 'GoferFoo-dkh.75';
		load.
	self assert: pkgBar workingCopy ancestry ancestors first name = 'GoferBar-jf.1'.
	self assert: (pkgBar workingCopy repositoryGroup includes: self monticelloRepository).
	self assert: pkgBar workingCopy repositoryGroup repositories size = 3.
	self assert: pkgFoo workingCopy ancestry ancestors first name = 'GoferFoo-dkh.75'.
	self assert: (pkgFoo workingCopy repositoryGroup includes: self alternateRepository).
	self assert: pkgFoo workingCopy repositoryGroup repositories size = 3.! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 15:14'!
testMoosePackageResolution

	|  ref pkg |
	pkg := GoferPackageReference name: 'GoferFaux'.
	ref := pkg resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 35.
	pkg := MetacelloGoferPackage name: 'GoferFaux' packageFilename: 'GoferFaux-'.
	ref := pkg resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 35.
	pkg := GoferPackageReference name: 'GoferFaux-'.
	self should: [ pkg resolveWith: gofer ] raise: Error.
	pkg := GoferVersionReference name: 'GoferFaux-'.
	self should: [ pkg resolveWith: gofer ] raise: Error.! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 1/12/2010 14:39'!
testPackageResolution
	|  project version repo pkg ref |
	project := self project.
	version := project version: '1.0-baseline'.
	repo := version spec repositorySpecs first createRepository.
	gofer repository: repo.
	pkg := GoferPackageReference name: 'GoferFoo'.
	ref := pkg resolveWith: gofer.
	self assert: ref versionNumber = 4.
	pkg := GoferPackageReference name: 'GoferBar'.
	ref := pkg resolveWith: gofer.
	self assert: ref versionNumber = 1.
	self assert: ref author = 'lr'.! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 12/22/2009 11:49'!
testPackagesNeedSaving
	| repoSpec repo project |
	project := self class new project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	gofer repository: repo.
	gofer package: 'GoferFoo'; package: 'GoferBar'; load.
	self assert: (project packagesNeedSaving: '1.0-baseline') isEmpty.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	self assert: (project packagesNeedSaving: '1.0-baseline') notEmpty.! !

!MetacelloGoferFunctionalTest methodsFor: 'versions' stamp: 'dkh 01/14/2010 14:26'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			package: 'Faux-Smalltalk' with: 'Faux-Smalltalk-tg.32';
			yourself. ].! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloMCCachingLoaderTestCase
	instanceVariableNames: 'platformCacheRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloMCCachingLoaderTestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 3/4/2010 14:39'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			package: 'GoferFaux';
			yourself ].! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:52'!
testBaselineFetch

	| project version repo map pkgSpecs |
	project := self project.
	version := project version: '1.0-baseline'.
	repo := version loaderPolicy cacheRepository.
	self assert: repo allVersionInfos isEmpty.
	version fetch: 'default'.
	self deny: repo allVersionInfos isEmpty.
	map := Dictionary new.
	(Gofer new allResolvedIn: repo) do: [:resolvedRef | map at: resolvedRef packageName put: resolvedRef ].
	pkgSpecs := version packages.
	self assert: map size = pkgSpecs size.
	pkgSpecs do: [:pkgSpec | map at: pkgSpec name ifAbsent: [ self assert: false ]].! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/4/2010 20:35'!
testBaselineLoad

	| project version wc |
	project := self project.
	version := project version: '1.0-baseline'.
	version load: #('default').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.35').! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:53'!
testDualFetch

	| project version repo map pkgSpecs |
	project := self project.
	version := project version: '2.0'.
	repo := version loaderPolicy cacheRepository.
	self assert: repo allVersionInfos isEmpty.
	version fetch: 'default'.
	self deny: repo allVersionInfos isEmpty.
	version := project version: '1.0-baseline'.
	version fetch: #('default').
	self deny: repo allVersionInfos isEmpty.
	map := Dictionary new.
	(Gofer new allResolvedIn: repo) do: [:resolvedRef | map at: resolvedRef packageName put: resolvedRef ].
	pkgSpecs := version packages.
	self assert: map size = pkgSpecs size.
	pkgSpecs do: [:pkgSpec | map at: pkgSpec name ifAbsent: [ self assert: false ]].! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:54'!
testVersion10Fetch

	| project version repo map pkgSpecs |
	project := self project.
	version := project version: '1.0'.
	repo := version loaderPolicy cacheRepository.
	self assert: repo allVersionInfos isEmpty.
	version fetch: #('default').
	self deny: repo allVersionInfos isEmpty.
	map := Dictionary new.
	(Gofer new allResolvedIn: repo) do: [:resolvedRef | map at: resolvedRef name put: resolvedRef ].
	pkgSpecs := version packages.
	self assert: map size = pkgSpecs size.
	pkgSpecs do: [:pkgSpec | map at: pkgSpec file ifAbsent: [ self assert: false ]].! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'versions' stamp: 'DaleHenrichs 3/4/2010 14:55'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.32';
			yourself. ].! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'versions' stamp: 'DaleHenrichs 3/4/2010 18:35'!
version20: spec
	<version: '2.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.35';
			yourself. ].! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloMCSpecLoaderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloMCSpecLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 1/20/2010 09:57'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			package: 'GoferFaux';
			yourself ].! !

!MetacelloMCSpecLoaderTest methodsFor: 'baselines' stamp: 'dkh 01/14/2010 12:30'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec repository: 'dictionary://Metacello_Configuration_Test_Alternate_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			yourself ].! !

!MetacelloMCSpecLoaderTest methodsFor: 'running' stamp: 'dkh 01/14/2010 16:53'!
tearDown
	super tearDown.
	MetacelloMonticelloResource reset. "testCommitPackageSpec modifies the repository resource"! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'dkh 01/14/2010 12:46'!
testCopySpec

	| project version loader repo fakePackage |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version spec loader.
	repo := MCDictionaryRepository new.
	self assert: repo allVersionInfos size = 0.
	loader 
		copySpec: (version packageNamed: 'GoferFoo')
		from: version spec repositorySpecs
		to: repo.
	self assert: repo allVersionInfos size = 1.
	
	"error condition"
	fakePackage := version packageNamed: 'GoferFoo'.
	fakePackage name: 'MetacelloTestConfigurationOfFoo'.
	self assert: (loader 
		copySpec: fakePackage
		from: version spec repositorySpecs
		to: repo) == nil! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 11:38'!
testGoferCommit

	| project version repoSpec repo allVersionsSize pkg |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	version load.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	pkg goferCommitPackage: 'commit message'.
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 15:15'!
testLatestPackage

	| project version loader latestFile |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version spec loader.
	latestFile := loader 
		latestPackage: 'GoferFoo' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile = 'GoferFoo-lr.4'.

	latestFile := loader 
		latestPackage: 'GoferBar' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile = 'GoferBar-lr.1'.

	latestFile := loader 
		latestPackage: 'GoferFaux' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile = 'GoferFaux-tg.35'.

	"error condition"
	latestFile := loader 
		latestPackage: 'MetacelloTestConfigurationOfFoo' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile == nil.! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 1/15/2010 10:03'!
testPackageSave

	| project version repoSpec repo allVersionsSize pkg |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	version load.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	[ pkg savePackage ]
		on: MCVersionNameAndMessageRequest
		do: [ :notifcation | notifcation resume: (Array with: notifcation suggestedName with: 'xxx') ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/5/2010 14:17'!
testPackageSpecLoad

	| project version repoSpec pkg wc |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	pkg load.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'dkh 01/14/2010 12:46'!
testRepositoryFor

	| project version loader pkgSpec repo1 repo2 |
	project := self project.
	version := project version: '2.0-baseline'.
	loader := version spec loader.
	pkgSpec := version packageNamed: 'GoferBar'.
	repo1 := self monticelloRepository.
	repo2 := self alternateRepository.

	pkgSpec file: 'GoferBar-lr.branch.1'.
	self assert: 
		(loader 
			repositoryFor: pkgSpec 
			from: version spec repositorySpecs) == repo1.
	pkgSpec file: 'GoferBar-dkh.25'.
	self assert: 
		(loader 
			repositoryFor: pkgSpec 
			from: version spec repositorySpecs) == repo2.

	"error condition"
	pkgSpec file: 'MetacelloTestConfigurationOfFoo-dkh.1'.
	self assert: 
		(loader 
			repositoryFor: pkgSpec 
			from: version spec repositorySpecs) == nil.! !

!MetacelloMCSpecLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/20/2010 09:57'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.32';
			yourself. ].! !

Object subclass: #MetacelloMCTestsAbstractConfig
	instanceVariableNames: 'project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

MetacelloMCTestsAbstractConfig subclass: #MetacelloExampleProjectConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloExampleProjectConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 1/21/2010 18:38'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ]].! !

!MetacelloMCTestsAbstractConfig methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:37'!
project

	| constructor |
	^project ifNil: [
		"Construct Metacello project"
		constructor := MetacelloVersionConstructor on: self.
		project := constructor project.
		project loader: MetacelloNullRecordingMCSpecLoader new.
		project].! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryExampleConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryExampleConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 21:14'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec
			project: 'UTF8' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					file: 'MetacelloVersionQueryMiscConfig';
					versionString: '1.0-baseline';
					loads: #('Misc-UTF8' ) ].
		spec 
			package: 'Example-Core' with: [ spec requires: #('UTF8' ) ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ].
		spec
			group: 'Core' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-TestsUI' );
			group: 'No UI' with: #('Core' 'Example-Tests' );
			"recursive group definition"
			group: 'UI' with: #('No UI' 'UI' 'Tests' ).].! !

!MetacelloVersionQueryExampleConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 2/8/2010 16:41'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ].
		spec
			group: 'Core' with: #('default' );
			group: 'default' with: #('Example-Core' ) ].! !

!MetacelloVersionQueryExampleConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 2/8/2010 17:07'!
baseline21: spec 
	<version: '2.1-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Core' with: [ spec requires: #('Example-Core' ) ].
		spec
			group: 'default' with: #('Example-Core' ) ].! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryLatestVersionConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'baselines' stamp: 'dkh 12/21/2009 14:48'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'simple baseleine:)'].! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version112: spec
	<version: '1.1.2' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #stable ].! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version120: spec
	<version: '1.2' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #stable ].! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version130: spec
	<version: '1.3' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #development ].! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version131: spec
	<version: '1.3.1' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #development ].! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version132: spec
	<version: '1.3.2' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #development ].! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryMasterConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryMasterConfig methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:50'!
baselineProject30: spec 
	<version: '3.0-baseline'>
	
	spec for: #common do: [
		spec
			project: 'XML' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					versionString: '1.0-baseline';
					loads: #('Misc-XML') ];
			project: 'Project Core' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Core') ];
			project: 'Project Tests' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Tests') ].
		spec 
			package: 'Master-Core' with: [ 
				spec 
					includes: #('Master-Platform');
					requires: #('Project Core' 'XML') ];
			package: 'Master-Platform';
			package: 'Master-Tests' with: [ 
				spec requires: #('Master-Core' 'Project Tests') ].
		spec
			group: 'Core' with: #('Master-Core');
			group: 'Tests' with: #('Master-Tests').].! !

!MetacelloVersionQueryMasterConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 1/22/2010 11:41'!
baselineProject31: spec 
	<version: '3.1-baseline'>
	
	spec for: #common do: [
		spec
			project: 'XML' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					loads: #('Misc-XML') ];
			project: 'Project Core' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Core') ];
			project: 'Project Tests' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Tests') ].
		spec 
			package: 'Master-Core' with: [ 
				spec 
					includes: #('Master-Platform');
					requires: #('Project Core' 'XML') ];
			package: 'Master-Platform';
			package: 'Master-Tests' with: [ 
				spec requires: #('Master-Core' 'Project Tests') ].
		spec
			group: 'Core' with: #('Master-Core');
			group: 'Tests' with: #('Master-Tests').].! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryMiscConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryMiscConfig methodsFor: 'baselines' stamp: 'dkh 10/22/2009 08:16'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Misc-UTF8';
			package: 'Misc-MD5';
			package: 'Misc-XML'.].! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryProjectConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryProjectConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 23:47'!
baselineProject20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec
			project: 'Example ALL' with: [
				spec
					className: 'MetacelloVersionQueryExampleConfig';
					versionString: '1.0-baseline';
					loads: #('ALL' ) ].
		spec 
			package: 'Project-Core' with: [ spec requires: 'Example ALL' ];
			package: 'Project-Tests' with: [ spec requires: 'Project-Core' ].
		spec
			group: 'Core' with: #('Project-Core' );
			group: 'Tests' with: #('Project-Tests' ).].! !

!MetacelloVersionQueryProjectConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 23:47'!
baselineProject21: spec 
	<version: '2.1-baseline'>
	
	spec for: #common do: [
		spec
			project: 'MD5' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					versionString: '1.0-baseline';
					loads: #('Misc-MD5' ) ];
			project: 'Example Core' with: [
				spec
					className: 'MetacelloVersionQueryExampleConfig';
					versionString: '1.0-baseline';
					loads: #('Core' ) ];
			project: 'Example Tests' with: [
				spec
					className: 'MetacelloVersionQueryExampleConfig';
					versionString: '1.0-baseline';
					loads: #('Example-Tests' ) ].
		spec 
			package: 'Project-Core' with: [ spec requires: #('Example Core' 'MD5' ) ];
			package: 'Project-Tests' with: [ spec requires: #('Project-Core' 'Example Tests' ) ].
		spec
			group: 'Core' with: #('Project-Core' );
			group: 'Tests' with: #('Project-Tests' ).].! !

TestCase subclass: #MetacelloConfigAPITestCase
	instanceVariableNames: 'alternatePreLoadExecuted preLoadExecuted postLoadExecuted preloadAnswer postloadAnswer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'dkh 12/30/2009 14:21'!
alternatePreloadForCore

	alternatePreLoadExecuted := true! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 12/30/2009 12:55'!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #testBlessing.
		spec 
			package: 'Example-Core' with: [ 
				spec 
					includes: 'Example-AddOn';
					file: 'Example-Core-anon.1';
					repository: 'http://www.example.com/or';
					preLoadDoIt: #preloadForCore;
					postLoadDoIt: #postloadForCore:package: ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 12/30/2009 12:55'!
baseline101: spec 
	<version: '1.0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: [
			spec value: #testBlessing ]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 12/30/2009 12:58'!
baseline102: spec 
	<version: '1.0.2-baseline'>
	
	spec for: #common do: [
		spec 
			preLoadDoIt: #preloadForCore;
			postLoadDoIt: #postloadForCore:package:.
		spec 
			package: 'Example-Core' with: [ spec includes: 'Example-AddOn' ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 12/30/2009 14:20'!
baseline103: spec 
	<version: '1.0.3-baseline' imports: #( '1.0.2-baseline' )>
	
	spec for: #common do: [
		spec 
			preLoadDoIt: #alternatePreloadForCore ]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 12/30/2009 14:22'!
baseline104: spec 
	<version: '1.0.4-baseline' imports: #( '1.0.2-baseline' )>
	
	spec for: #common do: [
		spec 
			preLoadDoIt: nil ]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/2/2010 12:42'!
baseline105: spec 
	<version: '1.0.5-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec repository: 'http://www.example.com/ob' ]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/2/2010 16:22'!
baseline106: spec 
	<version: '1.0.6-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec repositories: [
						spec 
							repository: 'http://www.example.com/or';
							repository: 'http://www.example.com/ob' ]]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 01/07/2010 16:50'!
baseline107: spec 
	<version: '1.0.7-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec 
					preLoadDoIt: #preloadForSupplyingAnswers;
					postLoadDoIt: #postloadForSupplyingAnswers;
					supplyingAnswers: #(#('preload' 'preload answer') #('postload' 'postload answer')) ];
			package: 'Example-Tests' with: [
				spec supplyingAnswers: 
					#(
						#('string' 'preload answer') 
						#('symbol' #'default')
						#('integer' 1)
						#('boolean' true)
						#('another boolean' false)
						#('character' $a)
					)]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/6/2010 18:18'!
baseline108: spec 
	<version: '1.0.8-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [ 
				spec requires: 'Example-Core' ]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/6/2010 18:29'!
baseline109: spec 
	<version: '1.0.9-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [ 
				spec includes: 'Example-Core' ]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/6/2010 19:03'!
baseline110: spec 
	<version: '1.1.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Base';
			package: 'Example-Test1' with: [ 
				spec 
					includes: 'Example-Core';
					requires: 'Example-Base' ];
			package: 'Example-Test2' with: [ 
				spec 
					includes: 'Example-Core';
					supplyingAnswers: #(#('captionMatch' 'answer')) ];
			package: 'Example-Test3' with: [ 
				spec 
					supplyingAnswers: #(#('captionMatch' 'answer'));
					requires: 'Example-Base' ];
			package: 'Example-Test4' with: [ 
				spec 
					includes: 'Example-Core';
					supplyingAnswers: #(#('captionMatch' 'answer'));
					requires: 'Example-Base' ];
			yourself].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/11/2010 14:45'!
baseline111: spec 
	<version: '1.1.1-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core'.
		spec for: #nested do: [
			spec
				package: 'Example-Base';
				yourself ]].
	spec for: #extra do: [
		spec
			package: 'Example-Test';
			yourself].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/11/2010 15:15'!
baseline112: spec 
	<version: '1.1.2-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core'.
		spec for: #nested do: [
			spec
				package: 'Example-Base';
				package: 'Example-Test-Nested';
				yourself ]].
	spec for: #extra do: [
		spec
			package: 'Example-Test';
			yourself].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'dkh 1/11/2010 15:27'!
baseline113: spec 
	<version: '1.1.3-baseline'>
	
	spec for: #outer do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Test';
			yourself].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 23:21'!
baseline114: spec 
	<version: '1.1.4-baseline'>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #preloadForProject;
					postLoadDoIt: #postloadForProject;
					yourself. ];
			yourself].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 1/21/2010 19:33'!
baseline115: spec 
	<version: '1.1.5-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec preLoadDoIt: #alternatePreloadForCore ]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 1/21/2010 20:32'!
baseline116: spec 
	<version: '1.1.6-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec preLoadDoIt: #alternatePreloadForCore ]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 1/21/2010 20:28'!
baseline117: spec 
	<version: '1.1.7-baseline' imports: #( '1.0-baseline' ) >
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' overrides: [ 
				spec 
					preLoadDoIt: #alternatePreloadForCore ]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 1/21/2010 20:28'!
baseline118: spec 
	<version: '1.1.8-baseline' imports: #( '1.0-baseline' ) >
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec 
					preLoadDoIt: #alternatePreloadForCore ]].! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 23:21'!
baseline119: spec 
	<version: '1.1.9-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' overrides: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #alternatePreloadForCore;
					yourself.]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 1/22/2010 10:17'!
baseline120: spec 
	<version: '1.2.0-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Copied Example' copyFrom: 'Example Project' with: [
				spec preLoadDoIt: #alternatePreloadForCore ]]! !

!MetacelloConfigAPITestCase methodsFor: 'private' stamp: 'dkh 01/07/2010 16:46'!
conditionResult: resultString 
	"GemStone unconditionally prints Symbols with quotes, Squeak and Pharo do not"

	^(((resultString 
		copyReplaceAll: '#preloadForSupplyingAnswers' with: '#''preloadForSupplyingAnswers''')
			copyReplaceAll: '#postloadForSupplyingAnswers' with: '#''postloadForSupplyingAnswers''')
				copyReplaceAll: '#default' with: '#''default''')! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'dkh 12/30/2009 12:05'!
postloadForCore: mcLoader package: pkgSpec

	postLoadExecuted := true! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 1/21/2010 19:46'!
postloadForProject

	postLoadExecuted := true! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 4/9/2010 12:31'!
postloadForSupplyingAnswers

	postloadAnswer := ProvideAnswerNotification signal: 'postload'! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'dkh 12/30/2009 12:05'!
preloadForCore

	preLoadExecuted := true! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 1/21/2010 20:05'!
preloadForProject

	preLoadExecuted := true! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'dkh 1/6/2010 20:19'!
preloadForSupplyingAnswers

	preloadAnswer := ProvideAnswerNotification signal: 'preload'! !

!MetacelloConfigAPITestCase methodsFor: 'accessing' stamp: 'dkh 1/11/2010 14:43'!
project

	^self projectWith: #()! !

!MetacelloConfigAPITestCase methodsFor: 'accessing' stamp: 'dkh 1/11/2010 14:42'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: self project: project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	project loader evalDoits: true.
	^project! !

!MetacelloConfigAPITestCase methodsFor: 'running' stamp: 'dkh 12/30/2009 14:17'!
setUp

	super setUp.
	alternatePreLoadExecuted := preLoadExecuted := postLoadExecuted := false! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'dkh 12/30/2009 12:50'!
testBlessing
	| project version |
	project := self project.

	version := project version: '1.0-baseline'.
	self assert: version blessing = #testBlessing! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'dkh 12/30/2009 12:56'!
testBlessingBlock
	| project version |
	project := self project.

	version := project version: '1.0.1-baseline'.
	self assert: version blessing = #testBlessing! !

!MetacelloConfigAPITestCase methodsFor: 'test baselines' stamp: 'dkh 1/11/2010 14:51'!
testNestedBaseline

	| project version packageNames |
	project := self projectWith: #().
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 1.
	self assert: (packageNames includes: 'Example-Core').

	project := self projectWith: #(#extra).
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 2.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Test').

	project := self projectWith: #(#nested).
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 2.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').

	project := self projectWith: #(nested extra).
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 3.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test').! !

!MetacelloConfigAPITestCase methodsFor: 'test baselines' stamp: 'dkh 1/11/2010 15:15'!
testNestedBaselineOrder

	| project version packageNames |
	project := self projectWith: #().
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 1.
	self assert: (packageNames includes: 'Example-Core').

	project := self projectWith: #(#extra).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 2.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Test').

	project := self projectWith: #(#nested).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 3.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test-Nested').

	project := self projectWith: #(nested extra).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 4.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test').
	self assert: (packageNames includes: 'Example-Test-Nested').

	project := self projectWith: #(extra nested).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 4.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test').
	self assert: (packageNames includes: 'Example-Test-Nested').! !

!MetacelloConfigAPITestCase methodsFor: 'test baselines' stamp: 'dkh 1/11/2010 15:32'!
testNestedVersionOrder

	| project version fileNames |
	project := self projectWith: #(outer).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 2.
	self assert: (fileNames includes: 'Example-Core-dkh.1').
	self assert: (fileNames includes: 'Example-Test-dkh.1').

	project := self projectWith: #(extra).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 1.
	self assert: (fileNames includes: 'Example-Core-dkh.3').

	project := self projectWith: #(extra nested).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 1.
	self assert: (fileNames includes: 'Example-Core-dkh.3').

	project := self projectWith: #(outer extra).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 2.
	self assert: (fileNames includes: 'Example-Core-dkh.3').
	self assert: (fileNames includes: 'Example-Test-dkh.1').

	project := self projectWith: #(outer #nested).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.2').

	project := self projectWith: #(outer nested extra).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.3').

	project := self projectWith: #(outer extra nested).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.2').

	project := self projectWith: #(extra nested outer ).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.1').! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'dkh 1/6/2010 18:29'!
testPackageIncludes
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.9-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	string := pkg printString.
	expected := 'spec name: ''Example-Core'''.
	self assert: string = expected.
	pkg := version packageNamed: 'Example-Tests'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Tests'';
	includes: #(''Example-Core'' ).'.
	self assert: string = expected! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'dkh 1/6/2010 19:07'!
testPackageIncludesRequiresSupplyingAnswers
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.1.0-baseline') spec.
	pkg := version packageNamed: 'Example-Test1'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test1'';
	requires: #(''Example-Base'' );
	includes: #(''Example-Core'' ).'.
	self assert: string = expected.

	pkg := version packageNamed: 'Example-Test2'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test2'';
	includes: #(''Example-Core'' );
	supplyingAnswers #( #( ''captionMatch'' ''answer'' ) ).'.
	self assert: string = expected.

	pkg := version packageNamed: 'Example-Test3'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test3'';
	requires: #(''Example-Base'' );
	supplyingAnswers #( #( ''captionMatch'' ''answer'' ) ).'.
	self assert: string = expected.

	pkg := version packageNamed: 'Example-Test4'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test4'';
	requires: #(''Example-Base'' );
	includes: #(''Example-Core'' );
	supplyingAnswers #( #( ''captionMatch'' ''answer'' ) ).'.
	self assert: string = expected.! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 1/21/2010 20:26'!
testPackagePreloadOverride
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.7-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'dkh 12/30/2009 12:14'!
testPackagePreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0-baseline') spec.
	self assert: (versionSpec packages map at: 'Example-Core') preLoadDoIt == #preloadForCore.
	self assert: (versionSpec packages map at: 'Example-Core') postLoadDoIt == #postloadForCore:package:.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 1/21/2010 20:28'!
testPackagePreloadWith
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.8-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'dkh 1/2/2010 17:01'!
testPackageRepositories
	| project versionSpec version pkg repositoryDescriptions string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.6-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	repositoryDescriptions := pkg repositorySpecs collect: [:repoSpec | repoSpec description ].
	self assert: repositoryDescriptions size = 2.
	self assert: (repositoryDescriptions includes: 'http://www.example.com/ob').
	self assert: (repositoryDescriptions includes: 'http://www.example.com/or').
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Core'';
	repositories: [
		spec
			repository: ''http://www.example.com/ob'';
			repository: ''http://www.example.com/or'' ].'.
	self assert: string = expected! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'dkh 1/2/2010 14:06'!
testPackageRepository
	| project versionSpec version pkg |
	project := self project.

	versionSpec := (version := project version: '1.0.5-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	self assert: pkg repositorySpecs first description = 'http://www.example.com/ob'! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'dkh 1/6/2010 18:21'!
testPackageRequires
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.8-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	string := pkg printString.
	expected := 'spec name: ''Example-Core'''.
	self assert: string = expected.
	pkg := version packageNamed: 'Example-Tests'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Tests'';
	requires: #(''Example-Core'' ).'.
	self assert: string = expected! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 4/9/2010 12:46'!
testPackageSupplyingAnswers
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.7-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	string := self conditionResult: pkg printString.
	expected := 'spec 
	name: ''Example-Core'';
	supplyingAnswers #( #( ''preload'' ''preload answer'' ) #( ''postload'' ''postload answer'' ) );
	preLoadDoIt: #''preloadForSupplyingAnswers'';
	postLoadDoIt: #''postloadForSupplyingAnswers''.'.
	self assert: string = expected.
	self assert: pkg answers = #(#('preload' 'preload answer') #('postload' 'postload answer')).

	self deny: preloadAnswer = 'preload answer'.
	self deny: postloadAnswer = 'postload answer'.
	version load.
	self assert: preloadAnswer = 'preload answer'.
	self assert: postloadAnswer = 'postload answer'.

	pkg := version packageNamed: 'Example-Tests'.
	string := self conditionResult: pkg printString.
	expected := 'spec 
	name: ''Example-Tests'';
	supplyingAnswers #( #( ''string'' ''preload answer'' ) #( ''symbol'' #''default'' ) #( ''integer'' 1 ) #( ''boolean'' true ) #( ''another boolean'' false ) #( ''character'' $a ) ).'.
	self assert: string = expected.! !

!MetacelloConfigAPITestCase methodsFor: 'test directives' stamp: 'DaleHenrichs 4/8/2010 16:38'!
testPrePostPackageLoadsDo
	| project version loader loadDirective preloaded count pkgloaded postloaded |
	project := self project.

	version := project version: '1.0-baseline'.
	loader := version fetch.
	loadDirective := loader loadDirective.
	pkgloaded := postloaded := preloaded := false.
	loadDirective directivesDo: [:directive |
		directive preLoadDo: [:pre |
			self deny: preloaded.			 
			self deny: pkgloaded.
			self deny: postloaded.
			preloaded := true.
			self assert: (#preloadForCore == pre spec preLoadDoIt) ].
		directive packageDo: [:pkg | 
			preloaded ifTrue: [ 
				self deny: postloaded.
				pkgloaded := true.
				pkg spec name = 'Example-Core' ]].
		directive postLoadDo: [:post | 
			self assert: preloaded.			 
			self assert: pkgloaded.
			self deny: postloaded.
			preloaded := false.
			postloaded := true.
			self assert: (#postloadForCore:package: == post spec postLoadDoIt) ]].
	self assert: postloaded! !

!MetacelloConfigAPITestCase methodsFor: 'test directives' stamp: 'DaleHenrichs 4/8/2010 16:48'!
testPrepostProjectLoadsDo
	| project version loader loadDirective x |
	project := self project.

	version := project version: '1.1.6-baseline'.
	loader := version fetch.
	loadDirective := loader loadDirective.
	loadDirective prepostLoadDirectivesDo: [:directive |
		directive preLoadDo: [:pre | self assert: (#alternatePreloadForCore == directive spec preLoadDoIt) ].
		directive postLoadDo: [:post | self assert: (#postloadForProject == directive spec postLoadDoIt) ]].! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 3/12/2010 11:16'!
testProjectPackage
	| project version loader |
	project := self project.

	version := project version: '1.1.4-baseline'.
	loader := version record.
	loader loadDirective versionDirectivesDo: [:directive | | versionSpec |
		(versionSpec := directive spec) ~~ nil
			ifTrue: [ 
				versionSpec versionString = '1.1.4-baseline'
					ifTrue: [ | projectSpec |
						projectSpec := (versionSpec packageNamed: 'Example Project' ifAbsent: [ self assert: false]) projectReference.
						self assert: projectSpec projectPackage file =  projectSpec projectPackage file ]]].! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 1/22/2010 10:17'!
testProjectPreloadCopyFrom
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.0-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load: 'Copied Example'.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 1/22/2010 10:18'!
testProjectPreloadCopyFromB
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.0-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load: 'Example Project'.
	self deny: alternatePreLoadExecuted.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 1/21/2010 20:34'!
testProjectPreloadOverride
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.9-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 1/21/2010 18:39'!
testProjectPreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.4-baseline') spec.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 1/21/2010 20:32'!
testProjectPreloadWith
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.6-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'dkh 12/30/2009 14:20'!
testVersionPreloadOverride
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0.3-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'dkh 12/30/2009 12:56'!
testVersionPreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0.2-baseline') spec.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'dkh 12/30/2009 14:24'!
testVersionPreloadRemove
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0.4-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'versions' stamp: 'dkh 1/11/2010 15:28'!
version113: spec 
	<version: '1.1.3' imports: #( '1.1.3-baseline' )>
	
	spec for: #outer do: [
		spec
			package: 'Example-Core' with: 'Example-Core-dkh.1';
			package: 'Example-Test' with: 'Example-Test-dkh.1'.
		spec for: #nested do: [
			spec
				package: 'Example-Core' with: 'Example-Core-dkh.2';
				yourself ]].
	spec for: #extra do: [
		spec
			package: 'Example-Core' with: 'Example-Core-dkh.3';
			yourself].! !

TestCase subclass: #MetacelloGoferPackageTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'dkh 1/13/2010 16:29'!
testClassMatch

	self assert: 
		(MetacelloGoferPackage 
			packageFileName: 'JQuery-Core.gemstone' 
			matchesPackageName: 'JQuery-Core').
	self assert: 
		(MetacelloGoferPackage 
			packageFileName: 'JQuery-Core.gemstone-dkh.100' 
			matchesPackageName: 'JQuery-Core').
	self assert: 
		(MetacelloGoferPackage 
			packageFileName: 'Sport-2.031' 
			matchesPackageName: 'Sport').! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 14:05'!
testInstanceMatch01

	self assert: 
		((MetacelloGoferPackage name: 'Faux-Smalltalk' packageFilename: 'Faux-Smalltalk-')
			matches: (GoferVersionReference name: 'Faux-Smalltalk-tg.34')).
	self deny: 
		((MetacelloGoferPackage name: 'Faux-Smalltalk' packageFilename: 'Faux-Smalltalk-')
			matches: (GoferVersionReference name: 'Faux-SmalltalkTesting-tg.34')).! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 14:30'!
testInstanceMatch02

	self deny: 
		((MetacelloGoferPackage name: 'GoferBar' packageFilename: 'GoferBar-lr.branch.2')
			matches: (GoferVersionReference name: 'GoferBar-jf.1')).! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 14:29'!
testInstanceMatch03

	self assert: 
		((MetacelloGoferPackage name: 'Faux-Smalltalk' packageFilename: 'Faux-Smalltalk-')
			matches: (GoferVersionReference name: 'Faux-Smalltalk-Testing-tg.34')).! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 14:33'!
testInstanceMatch04

	self deny: 
		((MetacelloGoferPackage name: 'ConfigurationOfMagritte' packageFilename: 'ConfigurationOfMagritte')
			matches: (GoferVersionReference name: 'ConfigurationOfMagritte2-dkh.137')).! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/19/2010 10:05'!
testInstanceMatch05

	self assert: 
		((MetacelloGoferPackage name: 'Seaside2' packageFilename: 'Seaside2.8')
			 matches: (GoferVersionReference name: 'Seaside2.8a1-lr.597')).! !

TestCase subclass: #MetacelloHTTPRepositoryLoadTestCase
	instanceVariableNames: 'gofer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'assertions' stamp: 'dkh 10/18/2009 10:33'!
assertClass: aClassSymbol
	self assert: (Smalltalk hasClassNamed: aClassSymbol)! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'assertions' stamp: 'dkh 10/18/2009 10:33'!
assertClass: aClassSymbol selector: aMethodSymbol
	self assertClass: aClassSymbol.
	self assert: ((Smalltalk at: aClassSymbol) includesSelector: aMethodSymbol)! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'baselines' stamp: 'dkh 10/18/2009 10:25'!
baseline: spec 
	<version: 'default'>

	spec
		for: #common
		do: [spec
				project: 'Bogus Project'
				with: [
					spec className: 'BogusConfiguration';
						 file: 'BogusConfiguration';
						 version: 'default';
						 repository: 'http://seaside.gemstone.com/ss/bogus']]! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'baselines' stamp: 'TestRunner 10/22/2009 10:21'!
baselineAuthentication: spec 
	<version: 'authentication'>

	spec
		for: #common
		do: [spec
				project: 'Bogus Project'
				with: [
					spec className: 'BogusConfiguration';
						 file: 'BogusConfiguration';
						 version: 'default';
						 repository: 'http://seaside.gemstone.com/ss/authenticationRequired' username: 'foo' password: 'bar']]! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'accessing' stamp: 'TestRunner 10/22/2009 10:20'!
enabled
	"return true to actually run tests ... don't need to test loading all of the time ...
	 before enabling this, see #testAuthentication"
	
	^false! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'utilities' stamp: 'dkh 10/18/2009 10:33'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'accessing' stamp: 'dkh 10/18/2009 09:27'!
project

	^(MetacelloVersionConstructor on: self) project! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'running' stamp: 'dkh 12/15/2009 11:03'!
setUp

	super setUp.
	gofer := Gofer new.
	gofer 
		gemsource: 'bogus'; 
		package: 'BogusConfiguration';
		package: 'Bogus';
		package: 'BogusExt'! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'running' stamp: 'dkh 10/18/2009 09:25'!
tearDown

	super tearDown.
	[ gofer unload ]
		on: Error
		do: [ :err | "assume it is not there" ]! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 10:20'!
testAuthentication
	"test _should_ fail because you are not authorized to access the repository...
	 to test with your own private repository copy the package BogusConfiguration from
	 http://seaside.gemstone.com/ss/bogus to your repository and edit the #baselineAuthentication:
	 appropriately. "

	self enabled ifFalse: [ ^self ].
	(self project version: 'authentication') load.
	self assert: (self hasPackage: 'Bogus'); assertClass: #BogusA.
	self assert: (self hasPackage: 'BogusExt'); assertClass: #BogusA selector: #isFake.! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'tests' stamp: 'dkh 12/30/2009 10:22'!
testLoad

	self enabled ifFalse: [ ^self ].
	(self project version: 'default') load.
	self assert: (self hasPackage: 'Bogus'); assertClass: #BogusA.
	self assert: (self hasPackage: 'BogusExt'); assertClass: #BogusA selector: #isFake.! !

TestCase subclass: #MetacelloImportsTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloImportsTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:46'!
baseline10beta0: spec 
	<version: '1.0-beta.0-baseline'>
	spec
		for: #common
		do: [
			spec
				package: 'Metacello-Core'
				with: [spec includes: #('Metacello-MC' 'Metacello-Platform' )];
				
				package: 'Metacello-MC';
				
				package: 'Metacello-Platform'
				with: [spec requires: #('Metacello-MC' )]].! !

!MetacelloImportsTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:46'!
baseline10beta3: spec 
	<version: '1.0-beta.3-baseline' imports: #('1.0-beta.0-baseline')>
	spec
		for: #common
		do: [
			spec
				package: 'Metacello-TestsCore'
				with: [spec requires: #('Metacello-Core' )];
				
				package: 'Metacello-Tutorial'
				with: [spec requires: #('Metacello-Core' )];
				
				package: 'Metacello-TutorialTests'
				with: [spec requires: #('Metacello-Tutorial' )]]! !

!MetacelloImportsTestCase methodsFor: 'accessing' stamp: 'dkh 10/17/2009 09:41'!
project

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	^project! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:09'!
testBaseline10beta0

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.0-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'Metacello-Core') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Platform') >
						(loadedPackages indexOf: 'Metacello-Core').! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:08'!
testBaseline10beta3

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.3-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Platform') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests') >
						(loadedPackages indexOf: 'Metacello-Tutorial').! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:06'!
testVersion10beta3

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.3'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Platform') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests') >
						(loadedPackages indexOf: 'Metacello-Tutorial').! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:18'!
testVersion10beta3Extra

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.3-extra'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core-dkh.1') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Platform-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Tutorial-dkh.1').! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:09'!
testVersion10beta3ImportedVersions
	| project version |
	project := self project.

	version := project version: '1.0-beta.3-baseline'.
	self assert: version importedVersions size = 1.
	self assert: (version importedVersions includes: '1.0-beta.0-baseline').

	version := project version: '1.0-beta.3'.
	self assert: version importedVersions size = 1.
	self assert: (version importedVersions includes: '1.0-beta.3-baseline').! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:19'!
testVersion10beta4

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.4'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core-dkh.1') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Platform-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Tutorial-dkh.1').! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:22'!
testVersion10beta4ImportedVersions

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.4'.
	self assert: version importedVersions size = 2.
	self assert: (version importedVersions includes: '1.0-beta.3').
	self assert: (version importedVersions includes: '1.0-beta.3-extra').! !

!MetacelloImportsTestCase methodsFor: 'versions' stamp: 'dkh 10/14/2009 09:12'!
version10beta3: spec 
	<version: '1.0-beta.3' imports: #('1.0-beta.3-baseline')>
	spec
		for: #common
		do: [ spec blessing: #development].! !

!MetacelloImportsTestCase methodsFor: 'versions' stamp: 'dkh 1/7/2010 19:16'!
version10beta3Extra: spec 
	<version: '1.0-beta.3-extra' imports: #('1.0-beta.3-baseline')>
	spec
		for: #common
		do: [
			spec
				package: 'Metacello-Core' with: 'Metacello-Core-dkh.1';
				package: 'Metacello-MC' with: 'Metacello-MC-dkh.1';
				package: 'Metacello-Platform' with: 'Metacello-Platform-dkh.1';
				package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
				package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.1';
				package: 'Metacello-TutorialTests' with: 'Metacello-TutorialTests-dkh.1' ].! !

!MetacelloImportsTestCase methodsFor: 'versions' stamp: 'dkh 1/7/2010 19:19'!
version10beta4: spec 
	<version: '1.0-beta.4' imports: #('1.0-beta.3' '1.0-beta.3-extra' )>
	spec
		for: #common
		do: [ spec blessing: #release].! !

TestCase subclass: #MetacelloLoadOrderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:46'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ]].! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:47'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ spec includes: #('Example-AddOn' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ]].! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:47'!
baseline12: spec 
	<version: '1.2-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ].
		spec
			group: 'Core' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-TestsUI' );
			group: 'No UI' with: #('Core' 'Example-Tests' ).].! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'TestRunner 10/24/2009 15:01'!
baseline300alpha5: spec 
	<version: '3.0.0-alpha5-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '3.0.0 baseline based on 3.0.0-alpha5'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Seaside-Core' with: [ spec requires: #('Grease-Core' ). ];
			package: 'Seaside-Canvas' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Session' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-Core' with: [ 
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Widgets' with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Environment' with: [ 
				spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Flow' with: [ 
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Development' with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Examples' with: [ 
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [ 
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'RSS-Core' with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' with: [ spec requires: #('RSS-Core' ). ];
			package: 'Javascript-Core' with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' with: [ spec requires: #('Javascript-Core' ). ];
			package: 'Scriptaculous-Core' with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' with: [ 
				spec requires: #('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' ). ];
			package: 'Seaside-HTML5' with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Email' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-FileSystem' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Slime' with: [ spec requires: #('Grease-Core' ). ];
			
			package: 'Grease-Tests-Core' with: [ spec requires: #('Grease-Core' ). ];
			package: 'Seaside-Tests-Core' with: [ spec requires: #('Seaside-Core' 'Grease-Tests-Core' ). ];
			package: 'Seaside-Tests-UTF8' with: [ spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Session' with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Component' with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [ 
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Environment' with: [ 
				spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Functional' with: [ 
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Flow' with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [ 
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Development' with: [ 
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Examples' with: [ 
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'RSS-Tests-Core' with: [ spec requires: #('RSS-Core' ). ];
			package: 'Javascript-Tests-Core' with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' with: [ 
				spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' with: [ 
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'Scriptaculous-Tests-Core' with: [ 
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' with: [ 
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [ 
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Email' with: [ spec requires: #('Seaside-Email' 'Seaside-Tools-Core' ) ];
			package: 'Seaside-Tests-FileSystem' with: [ spec requires: #('Seaside-FileSystem' ). ];
			package: 'Seaside-Tests-Slime' with: [ spec requires: #('Seaside-Slime' ). ]].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Seaside-Core' with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Environment' with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];
			package: 'Seaside-Email' with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Javascript-Core' with: [ spec includes: #('Javascript-Pharo-Core' ) ];

			package: 'Grease-Tests-Core' with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Functional' with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Tests-Flow' with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Development' with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			
			package: 'Grease-Pharo-Core' with: [ spec requires: #('Grease-Core' ) ];
			package: 'Seaside-Pharo-Core' with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-Pharo-Environment' with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-Pharo-Continuation' with: [ spec requires: #('Grease-Core' ) ];
			package: 'Seaside-Pharo-Flow' with: [ spec requires: #('Seaside-Flow' 'Grease-Core' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-Web' with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-Pharo-Development' with: [ spec requires: #('Seaside-Development' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Email' with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Comet-Pharo-Core' with: [ spec requires: #('Comet-Core' ) ];

			package: 'Javascript-Pharo-Core' with: [ spec requires: #('Javascript-Core' ) ];
			package: 'DynamicBindings' with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomServices' with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomHttpServer' with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'Seaside-Adaptors-Comanche' with: [ 
				spec requires: #('Seaside-Core' 'DynamicBindings' 'KomServices' 'KomHttpServer' ) ];
			package: 'Seaside-Adaptors-Swazoo' with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];
			package: 'Comet-Core' with: [ 
				spec includes: #('Comet-Pharo-Core' ).
				spec requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			package: 'Seaside-Swazoo' with: [ spec requires: #('Grease-Core' ). ];

			package: 'Grease-Tests-Pharo-Core' with: [ spec requires: #('Grease-Tests-Core' ) ];
			package: 'Seaside-Tests-Pharo-Core' with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Pharo-Functional' with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [ 
				spec requires: #('Seaside-Pharo-Continuation' 'Grease-Tests-Core' ) ];
			package: 'Seaside-Tests-Pharo-Development' with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [ 
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Core' )];
			package: 'Comet-Tests-Core' with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ]].! !

!MetacelloLoadOrderTestCase methodsFor: 'accessing' stamp: 'dkh 10/17/2009 09:41'!
project

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	^project! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/17/2009 10:10'!
testBaseline10
	| loadedPackages project loader |
	project := self class new project.
	loader := project load: '1.0-baseline'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/17/2009 10:11'!
testBaseline11
	| loadedPackages project loader |
	project := self class new project.
	loader := project load: '1.1-baseline'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/21/2009 11:16'!
testBaseline12
	| loadedPackages project loader |
	project := self class new project.
	loader := (project version: '1.2-baseline') load: 'No UI'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI') = 0.
	self assert: (loadedPackages indexOf: 'Example-TestsUI') = 0.! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/17/2009 10:12'!
testBaseline300alpha5IncludesX
	"make sure that includes: constraints are met"
	"the includes: directive should slave the included package such that included packages are 
	 loaded before any of the packages that require the base package."
	
	| project loadedPackageNames loadedPackageSpecs baseSpecName loader |
	project := self class new project.
	loader := project load: '3.0.0-alpha5-baseline'.
	loadedPackageNames := loader loadedPackages asArray.
	loadedPackageSpecs := loader packages.
	loadedPackageSpecs do: [:baseSpec |
		baseSpecName := baseSpec name.
		"this only applies to packageSpecs, groups are not treated this way"
		baseSpec includes do: [:includedSpecName |
			loadedPackageSpecs do: [:spec |
				(spec requires includes: baseSpecName)
					ifTrue: [
						self assert: 
							((loadedPackageNames indexOf: spec name) >=
								(loadedPackageNames indexOf: includedSpecName)).
						self assert: 
							((loadedPackageNames indexOf: spec name) >
								(loadedPackageNames indexOf: baseSpecName)) ].
				(spec requires includes: includedSpecName)
					ifTrue: [
						self assert: 
							((loadedPackageNames indexOf: spec name) >
								(loadedPackageNames indexOf: includedSpecName)) ]]]].! !

TestCase subclass: #MetacelloPlatformAttributesTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloPlatformAttributesTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:48'!
baseline011: spec 
	<version: '0.11-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'FFI project '.
		spec repository: 'source.squeakfoundation.org/FFI'.

		spec 
			package: 'FFI-Kernel';
			package: 'FFI-Examples' with: [
				spec requires: #('FFI-Kernel' ) ];
			package: 'FFI-Tests' with: [
				spec requires: #('FFI-Examples' ) ]].! !

!MetacelloPlatformAttributesTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:49'!
baseline10beta0: spec 
	<version: '1.0-beta.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'GemTools client for Pharo/Squeak'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec requires: #('OB-SUnitGUI' ) ];
			package: 'GemTools-Platform' with: [
				spec requires: #('GemTools-Client' ) ]].! !

!MetacelloPlatformAttributesTestCase methodsFor: 'accessing' stamp: 'dkh 10/14/2009 16:40'!
project

	^self projectWith: #()! !

!MetacelloPlatformAttributesTestCase methodsFor: 'accessing' stamp: 'dkh 10/17/2009 09:41'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: self project: project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	^project! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:13'!
testBaseline011
	| project loadedPackages version loader |
	project := self project.

	version := project version: '0.11-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples') >
						(loadedPackages indexOf: 'FFI-Kernel').
	self assert: (loadedPackages indexOf: 'FFI-Tests') >
						(loadedPackages indexOf: 'FFI-Examples').! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testBaseline011Pharo10Beta
	| project loadedPackages version loader |
	project := self projectWith: #(#'pharo1.0Beta').

	version := project version: '0.11-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples') >
						(loadedPackages indexOf: 'FFI-Kernel').
	self assert: (loadedPackages indexOf: 'FFI-Tests') >
						(loadedPackages indexOf: 'FFI-Examples').! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testVersion011
	| project loadedPackages version loader |
	project := self project.

	version := project version: '0.11'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel-ar.8') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples-ar.1') >
						(loadedPackages indexOf: 'FFI-Kernel-ar.8').
	self assert: (loadedPackages indexOf: 'FFI-Tests-ar.2') >
						(loadedPackages indexOf: 'FFI-Examples-ar.1').! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testVersion011Pharo10Beta
	| project loadedPackages version loader |
	project := self projectWith: #(#'pharo1.0Beta').

	version := project version: '0.11'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel-ar.11') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples-ar.1') >
						(loadedPackages indexOf: 'FFI-Kernel-ar.11').
	self assert: (loadedPackages indexOf: 'FFI-Tests-ar.3') >
						(loadedPackages indexOf: 'FFI-Examples-ar.1').! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testVersion10beta0
	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.0'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'OB-SUnitGUI-dkh.52') >
						(loadedPackages indexOf: 'FFI-Tests-ar.3').
	self assert: (loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493') >
						(loadedPackages indexOf: 'OB-SUnitGUI-dkh.52').
	self assert: (loadedPackages indexOf: 'GemTools-Platform.squeakCommon-dkh.2') >
						(loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493').! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:15'!
testVersion10beta0Pharo10Beta
	| project loadedPackages version loader |
	project := self projectWith: #(#'pharo1.0Beta').

	version := project version: '1.0-beta.0'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'OB-SUnitGUI-dkh.52') >
						(loadedPackages indexOf: 'FFI-Tests-ar.3').
	self assert: (loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493') >
						(loadedPackages indexOf: 'OB-SUnitGUI-dkh.52').
	self assert: (loadedPackages indexOf: 'GemTools-Platform.pharo10beta-dkh.2') >
						(loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493').! !

!MetacelloPlatformAttributesTestCase methodsFor: 'versions' stamp: 'dkh 10/16/2009 13:39'!
version011: spec 
	<version: '0.11' imports: #('0.11-baseline' )>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'FFI project ... used by GemTools for Pharo 1.0beta #10440'.
		spec 
			package: 'FFI-Kernel' with: 'FFI-Kernel-ar.8';
			package: 'FFI-Examples' with: 'FFI-Examples-ar.1';
			package: 'FFI-Tests' with: 'FFI-Tests-ar.2' ].
	spec for: #'pharo1.0Beta' do: [
		spec 
			package: 'FFI-Kernel' with: 'FFI-Kernel-ar.11';
			package: 'FFI-Tests' with: 'FFI-Tests-ar.3' ].! !

!MetacelloPlatformAttributesTestCase methodsFor: 'versions' stamp: 'dkh 10/16/2009 13:39'!
version10beta0: spec 
	<version: '1.0-beta.0' imports: #('1.0-beta.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'GemTools client for Pharo/Squeak'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client.experimental-dkh.493';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.2' ].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.2' ].! !

TestCase subclass: #MetacelloVersionQueryTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloVersionQueryTestCase methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:40'!
exampleProject

	^MetacelloVersionQueryExampleConfig new project! !

!MetacelloVersionQueryTestCase methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:40'!
masterProject

	^MetacelloVersionQueryMasterConfig new project! !

!MetacelloVersionQueryTestCase methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:40'!
projectProject

	^MetacelloVersionQueryProjectConfig new project! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:04'!
testBaseline10Groups
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Core' 'Tests' 'No UI' 'UI').
	list := version groups.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 13:42'!
testBaseline10Load
	| loadedPackages project loader |
	project := self exampleProject.
	loader := (project version: '1.0-baseline') load: 'UI'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10Packages
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI').
	list := version packages.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed01
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core').
	list := version packagesForSpecNamed: 'Example-Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed02
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #().
	list := version packagesForSpecNamed: 'None existent'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/21/2009 14:16'!
testBaseline10PackagesForSpecNamed03
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI').
	list := version packagesForSpecNamed: 'ALL'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed04
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' ).
	list := version packagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed05
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' ).
	list := version packagesForSpecNamed: 'No UI'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/21/2009 14:35'!
testBaseline10PackagesForSpecNamed06
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-TestsUI').
	list := version packagesForSpecNamed: 'UI'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed07
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI').
	list := version packagesForSpecNamed: 'default'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:21'!
testBaseline10PackagesForSpecNamed08
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-TestsUI' 'Example-UI' 'Misc-UTF8' ).
	list := version allPackagesForSpecNamed: { 'No UI'. 'UI'. 'Tests'. }.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:22'!
testBaseline10Projects
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('UTF8').
	list := version projects.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'test resolveToLoadableSpecs' stamp: 'DaleHenrichs 1/19/2010 12:12'!
testBaseline10ResolveToLoadableSpecs01
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.

	expected := #('Example-Core' 'UTF8').
	list := version resolveToLoadableSpecs: #('Example-Core').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].

	expected := #('Example-AddOn' 'Example-Core' 'UTF8').
	list := version resolveToLoadableSpecs: #('Example-AddOn').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].

	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'UTF8').
	list := version resolveToLoadableSpecs: #('No UI').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20Groups
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Core' 'Tests').
	list := version groups.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 2/8/2010 17:11'!
testBaseline20Load
	| project version |
	project := self exampleProject.
	version := project currentVersionAgainst: #('Core') "in 2.1 'Core' is a package and in 2.0 'Core' is a group ... no errors"! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20Packages
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Project-Tests').
	list := version packages.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20PackagesForSpecNamed01
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core').
	list := version packagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:23'!
testBaseline20PackagesForSpecNamed02
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI' 'Misc-UTF8').
	list := version allPackagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20PackagesForSpecNamed03
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Project-Tests').
	list := version packagesForSpecNamed: 'ALL'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:23'!
testBaseline20PackagesForSpecNamed04
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Project-Tests' 'Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI' 'Misc-UTF8').
	list := version allPackagesForSpecNamed: 'ALL'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20Projects
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Example ALL').
	list := version projects.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:24'!
testBaseline21PackagesForSpecNamed01
	| project version expected list |
	project := self projectProject.
	version := project version: '2.1-baseline'.
	expected := #('Project-Core' 'Example-Core' 'Example-AddOn' 'Misc-UTF8' 'Misc-MD5').
	list := version allPackagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:25'!
testBaseline21PackagesForSpecNamed02
	| project version expected list |
	project := self projectProject.
	version := project version: '2.1-baseline'.
	expected := #('Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Misc-UTF8' 'Misc-MD5').
	list := version allPackagesForSpecNamed: 'Tests'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline30Groups
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Core' 'Tests').
	list := version groups.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/21/2009 16:23'!
testBaseline30Packages
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Tests' 'Master-Platform' ).
	list := version packages.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:26'!
testBaseline30PackagesForSpecNamed01
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:26'!
testBaseline30PackagesForSpecNamed02
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Master-Tests' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: 'Tests'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:27'!
testBaseline30PackagesForSpecNamed03
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Master-Tests' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: { 'Tests'. }.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:27'!
testBaseline30Projects
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Project Core' 'Project Tests' 'XML').
	list := version projects.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'test resolveToLoadableSpecs' stamp: 'DaleHenrichs 1/19/2010 15:18'!
testBaseline30ResolveToLoadableSpecs01
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.

	expected := #('Master-Core' 'Master-Platform' 'Project Core' 'XML').
	list := version resolveToLoadableSpecs: #('Core').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 1/22/2010 11:41'!
testBaseline31PackagesForSpecNamed03
	| project version expected list |
	project := self masterProject.
	version := project version: '3.1-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Master-Tests' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: { 'Tests'. }.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'test latest filter' stamp: 'dkh 12/21/2009 14:59'!
testLatestFilter
	| project |
	project := MetacelloVersionQueryLatestVersionConfig new project.

	self assert: (project latestVersionMatching: '*.*') versionString = '1.2'.
	self assert: (project latestVersionMatching: '*.*.*') versionString = '1.1.2'.
	self assert: (project 
		latestVersionMatching: '*.*'
		includedBlessings: #(#development)) versionString = '1.3'.
	self assert: (project 
		latestVersionMatching: '*.*.*'
		includedBlessings: #(#development)) versionString = '1.3.2'.
	self assert: (project 
		latestVersionMatching: '*.*'
		excludedBlessings: #()) versionString = '1.3'.
	self assert: (project 
		latestVersionMatching: '*.?'
		includedBlessings: #(#development)) versionString = '1.3.2'.
	self assert: (project 
		latestVersionMatching: '*.?'
		excludedBlessings: #()) versionString = '1.3.2'.
	self assert: (project latestVersionMatching: '*') = nil! !
